use super::Element;

#[cfg(feature = "ranges")]
/// Range from the minimum to the maximum atomic radius across all elements
///
/// Convenience constant to avoid writing the code below when this range is needed:
///
/// ```
/// use mendeleev::{Element, ATOMIC_RADIUS_RANGE};
/// let all_values = Element::iter().flat_map(|e| e.atomic_radius());
/// let min = all_values.clone().min_by(|a, b| a.total_cmp(&b)).unwrap();
/// let max = all_values.max_by(|a, b| a.total_cmp(&b)).unwrap();
/// assert_eq!(min..=max, ATOMIC_RADIUS_RANGE);
/// ```
pub const ATOMIC_RADIUS_RANGE: core::ops::RangeInclusive<f64> = 25.0..=260.0;

impl Element {
    /// Returns the element's empirically measured atomic radius in pm, if available.
    ///
    /// ```
    /// use mendeleev::Element;
    /// assert_eq!(Element::H.atomic_radius(), Some(25.0));
    /// ```
    pub const fn atomic_radius(&self) -> Option<f64> {
        match self {
            Element::H => Some(25.0),
            Element::He => Some(120.0),
            Element::Li => Some(145.0),
            Element::Be => Some(105.0),
            Element::B => Some(85.0),
            Element::C => Some(70.0),
            Element::N => Some(65.0),
            Element::O => Some(60.0),
            Element::F => Some(50.0),
            Element::Ne => Some(160.0),
            Element::Na => Some(180.0),
            Element::Mg => Some(150.0),
            Element::Al => Some(125.0),
            Element::Si => Some(110.0),
            Element::P => Some(100.0),
            Element::S => Some(100.0),
            Element::Cl => Some(100.0),
            Element::Ar => Some(71.0),
            Element::K => Some(220.0),
            Element::Ca => Some(180.0),
            Element::Sc => Some(160.0),
            Element::Ti => Some(140.0),
            Element::V => Some(135.0),
            Element::Cr => Some(140.0),
            Element::Mn => Some(140.0),
            Element::Fe => Some(140.0),
            Element::Co => Some(135.0),
            Element::Ni => Some(135.0),
            Element::Cu => Some(135.0),
            Element::Zn => Some(135.0),
            Element::Ga => Some(130.0),
            Element::Ge => Some(125.0),
            Element::As => Some(115.0),
            Element::Se => Some(115.0),
            Element::Br => Some(115.0),
            Element::Kr => None,
            Element::Rb => Some(235.0),
            Element::Sr => Some(200.0),
            Element::Y => Some(180.0),
            Element::Zr => Some(155.0),
            Element::Nb => Some(145.0),
            Element::Mo => Some(145.0),
            Element::Tc => Some(135.0),
            Element::Ru => Some(130.0),
            Element::Rh => Some(135.0),
            Element::Pd => Some(140.0),
            Element::Ag => Some(160.0),
            Element::Cd => Some(155.0),
            Element::In => Some(155.0),
            Element::Sn => Some(145.0),
            Element::Sb => Some(145.0),
            Element::Te => Some(140.0),
            Element::I => Some(140.0),
            Element::Xe => None,
            Element::Cs => Some(260.0),
            Element::Ba => Some(215.0),
            Element::La => Some(195.0),
            Element::Ce => Some(185.0),
            Element::Pr => Some(185.0),
            Element::Nd => Some(185.0),
            Element::Pm => Some(185.0),
            Element::Sm => Some(185.0),
            Element::Eu => Some(185.0),
            Element::Gd => Some(180.0),
            Element::Tb => Some(175.0),
            Element::Dy => Some(175.0),
            Element::Ho => Some(175.0),
            Element::Er => Some(175.0),
            Element::Tm => Some(175.0),
            Element::Yb => Some(175.0),
            Element::Lu => Some(175.0),
            Element::Hf => Some(155.0),
            Element::Ta => Some(145.0),
            Element::W => Some(135.0),
            Element::Re => Some(135.0),
            Element::Os => Some(130.0),
            Element::Ir => Some(135.0),
            Element::Pt => Some(135.0),
            Element::Au => Some(135.0),
            Element::Hg => Some(150.0),
            Element::Tl => Some(190.0),
            Element::Pb => Some(180.0),
            Element::Bi => Some(160.0),
            Element::Po => Some(190.0),
            Element::At => None,
            Element::Rn => None,
            Element::Fr => None,
            Element::Ra => Some(215.0),
            Element::Ac => Some(195.0),
            Element::Th => Some(180.0),
            Element::Pa => Some(180.0),
            Element::U => Some(175.0),
            Element::Np => Some(175.0),
            Element::Pu => Some(175.0),
            Element::Am => Some(175.0),
            Element::Cm => None,
            Element::Bk => None,
            Element::Cf => None,
            Element::Es => None,
            Element::Fm => None,
            Element::Md => None,
            Element::No => None,
            Element::Lr => None,
            Element::Rf => None,
            Element::Db => None,
            Element::Sg => None,
            Element::Bh => None,
            Element::Hs => None,
            Element::Mt => None,
            Element::Ds => None,
            Element::Rg => None,
            Element::Cn => None,
            Element::Nh => None,
            Element::Fl => None,
            Element::Mc => None,
            Element::Lv => None,
            Element::Ts => None,
            Element::Og => None,
        }
    }
}
