use super::Element;

#[cfg(feature = "ranges")]
/// Range from the minimum to the maximum evaporation heat across all elements
///
/// Convenience constant to avoid writing the code below when this range is needed:
///
/// ```
/// use mendeleev::{Element, EVAPORATION_HEAT_RANGE};
/// let all_values = Element::iter().flat_map(|e| e.evaporation_heat());
/// let min = all_values.clone().min_by(|a, b| a.total_cmp(&b)).unwrap();
/// let max = all_values.max_by(|a, b| a.total_cmp(&b)).unwrap();
/// assert_eq!(min..=max, EVAPORATION_HEAT_RANGE);
/// ```
pub const EVAPORATION_HEAT_RANGE: core::ops::RangeInclusive<f64> = 0.08..=824.0;

impl Element {
    /// Returns the element's evaporation heat in kJ/mol, if known.
    ///
    /// ```
    /// use mendeleev::Element;
    /// assert_eq!(Element::H.evaporation_heat(), Some(0.904));
    /// ```
    pub const fn evaporation_heat(&self) -> Option<f64> {
        match self {
            Element::H => Some(0.904),
            Element::He => Some(0.08),
            Element::Li => Some(148.0),
            Element::Be => Some(309.0),
            Element::B => Some(504.5),
            Element::C => None,
            Element::N => None,
            Element::O => None,
            Element::F => Some(6.54),
            Element::Ne => Some(1.74),
            Element::Na => Some(97.9),
            Element::Mg => Some(131.8),
            Element::Al => Some(284.1),
            Element::Si => Some(383.0),
            Element::P => Some(49.8),
            Element::S => Some(10.5),
            Element::Cl => Some(20.41),
            Element::Ar => Some(6.52),
            Element::K => Some(2.33),
            Element::Ca => Some(153.6),
            Element::Sc => Some(332.7),
            Element::Ti => Some(422.6),
            Element::V => Some(460.0),
            Element::Cr => Some(342.0),
            Element::Mn => Some(221.0),
            Element::Fe => Some(340.0),
            Element::Co => Some(389.1),
            Element::Ni => Some(378.6),
            Element::Cu => Some(304.6),
            Element::Zn => Some(114.8),
            Element::Ga => Some(270.3),
            Element::Ge => Some(328.0),
            Element::As => Some(32.4),
            Element::Se => Some(59.7),
            Element::Br => Some(29.56),
            Element::Kr => Some(9.05),
            Element::Rb => Some(75.8),
            Element::Sr => Some(144.0),
            Element::Y => Some(367.0),
            Element::Zr => Some(567.0),
            Element::Nb => Some(680.0),
            Element::Mo => Some(590.0),
            Element::Tc => Some(585.0),
            Element::Ru => None,
            Element::Rh => Some(494.0),
            Element::Pd => Some(372.4),
            Element::Ag => Some(254.1),
            Element::Cd => Some(59.1),
            Element::In => Some(225.1),
            Element::Sn => Some(296.0),
            Element::Sb => Some(195.2),
            Element::Te => Some(49.8),
            Element::I => Some(41.95),
            Element::Xe => Some(12.65),
            Element::Cs => Some(68.3),
            Element::Ba => Some(142.0),
            Element::La => Some(402.0),
            Element::Ce => Some(398.0),
            Element::Pr => Some(331.0),
            Element::Nd => Some(289.0),
            Element::Pm => None,
            Element::Sm => Some(165.0),
            Element::Eu => Some(176.0),
            Element::Gd => Some(398.0),
            Element::Tb => Some(389.0),
            Element::Dy => Some(291.0),
            Element::Ho => Some(301.0),
            Element::Er => Some(317.0),
            Element::Tm => Some(232.0),
            Element::Yb => Some(159.0),
            Element::Lu => Some(414.0),
            Element::Hf => Some(575.0),
            Element::Ta => Some(758.0),
            Element::W => Some(824.0),
            Element::Re => Some(704.0),
            Element::Os => Some(738.0),
            Element::Ir => Some(604.0),
            Element::Pt => Some(470.0),
            Element::Au => Some(340.0),
            Element::Hg => Some(58.5),
            Element::Tl => Some(162.4),
            Element::Pb => Some(177.8),
            Element::Bi => Some(172.0),
            Element::Po => Some(102.9),
            Element::At => None,
            Element::Rn => Some(18.1),
            Element::Fr => None,
            Element::Ra => Some(113.0),
            Element::Ac => Some(292.9),
            Element::Th => Some(513.7),
            Element::Pa => Some(481.2),
            Element::U => Some(417.0),
            Element::Np => Some(336.0),
            Element::Pu => Some(343.5),
            Element::Am => Some(238.5),
            Element::Cm => None,
            Element::Bk => None,
            Element::Cf => None,
            Element::Es => None,
            Element::Fm => None,
            Element::Md => None,
            Element::No => None,
            Element::Lr => None,
            Element::Rf => None,
            Element::Db => None,
            Element::Sg => None,
            Element::Bh => None,
            Element::Hs => None,
            Element::Mt => None,
            Element::Ds => None,
            Element::Rg => None,
            Element::Cn => None,
            Element::Nh => None,
            Element::Fl => None,
            Element::Mc => None,
            Element::Lv => None,
            Element::Ts => None,
            Element::Og => None,
        }
    }
}
