use super::Isotope;

#[cfg(feature = "ranges")]
/// Range from the minimum to the maximum natural abundance across all isotopes
///
/// Only counts the isotopes that occur naturally in some amount, so the minimum is not 0.
///
/// Convenience constant to avoid writing the code below when this range is needed:
///
/// ```
/// use mendeleev::{Isotope, ISOTOPE_NATURAL_ABUNDANCE_RANGE};
/// let all_values = Isotope::iter().flat_map(|e| e.natural_abundance());
/// let min = all_values.clone().min_by(|a, b| a.total_cmp(&b)).unwrap();
/// let max = all_values.max_by(|a, b| a.total_cmp(&b)).unwrap();
/// assert_eq!(min..=max, ISOTOPE_NATURAL_ABUNDANCE_RANGE);
/// ```
pub const ISOTOPE_NATURAL_ABUNDANCE_RANGE: core::ops::RangeInclusive<f64> = 0.0002..=100.0;

impl Isotope {
    /// The isotopes relative natural abundance on Earth, as a percentage,
    /// or None if the isotope does not occur naturally or only in trace amounts
    ///
    /// ```
    /// use mendeleev::Isotope;
    /// assert_eq!(Isotope::H1.natural_abundance(), Some(99.9855));
    /// assert_eq!(Isotope::H3.natural_abundance(), None);
    /// assert_eq!(Isotope::Og295.natural_abundance(), None);
    /// ```
    pub const fn natural_abundance(&self) -> Option<f64> {
        match self {
            Isotope::H1 => Some(99.9855),
            Isotope::H2 => Some(0.0145),
            Isotope::H3 => None,
            Isotope::H4 => None,
            Isotope::H5 => None,
            Isotope::H6 => None,
            Isotope::H7 => None,
            Isotope::He3 => Some(0.0002),
            Isotope::He4 => Some(99.9998),
            Isotope::He5 => None,
            Isotope::He6 => None,
            Isotope::He7 => None,
            Isotope::He8 => None,
            Isotope::He9 => None,
            Isotope::He10 => None,
            Isotope::Li3 => None,
            Isotope::Li4 => None,
            Isotope::Li5 => None,
            Isotope::Li6 => Some(4.85),
            Isotope::Li7 => Some(95.15),
            Isotope::Li8 => None,
            Isotope::Li9 => None,
            Isotope::Li10 => None,
            Isotope::Li11 => None,
            Isotope::Li12 => None,
            Isotope::Li13 => None,
            Isotope::Be5 => None,
            Isotope::Be6 => None,
            Isotope::Be7 => None,
            Isotope::Be8 => None,
            Isotope::Be9 => Some(100.0),
            Isotope::Be10 => None,
            Isotope::Be11 => None,
            Isotope::Be12 => None,
            Isotope::Be13 => None,
            Isotope::Be14 => None,
            Isotope::Be15 => None,
            Isotope::Be16 => None,
            Isotope::B6 => None,
            Isotope::B7 => None,
            Isotope::B8 => None,
            Isotope::B9 => None,
            Isotope::B10 => Some(19.65),
            Isotope::B11 => Some(80.35),
            Isotope::B12 => None,
            Isotope::B13 => None,
            Isotope::B14 => None,
            Isotope::B15 => None,
            Isotope::B16 => None,
            Isotope::B17 => None,
            Isotope::B18 => None,
            Isotope::B19 => None,
            Isotope::B20 => None,
            Isotope::B21 => None,
            Isotope::C8 => None,
            Isotope::C9 => None,
            Isotope::C10 => None,
            Isotope::C11 => None,
            Isotope::C12 => Some(98.94),
            Isotope::C13 => Some(1.06),
            Isotope::C14 => None,
            Isotope::C15 => None,
            Isotope::C16 => None,
            Isotope::C17 => None,
            Isotope::C18 => None,
            Isotope::C19 => None,
            Isotope::C20 => None,
            Isotope::C21 => None,
            Isotope::C22 => None,
            Isotope::C23 => None,
            Isotope::N10 => None,
            Isotope::N11 => None,
            Isotope::N12 => None,
            Isotope::N13 => None,
            Isotope::N14 => Some(99.6205),
            Isotope::N15 => Some(0.3795),
            Isotope::N16 => None,
            Isotope::N17 => None,
            Isotope::N18 => None,
            Isotope::N19 => None,
            Isotope::N20 => None,
            Isotope::N21 => None,
            Isotope::N22 => None,
            Isotope::N23 => None,
            Isotope::N24 => None,
            Isotope::N25 => None,
            Isotope::O11 => None,
            Isotope::O12 => None,
            Isotope::O13 => None,
            Isotope::O14 => None,
            Isotope::O15 => None,
            Isotope::O16 => Some(99.757),
            Isotope::O17 => Some(0.03835),
            Isotope::O18 => Some(0.2045),
            Isotope::O19 => None,
            Isotope::O20 => None,
            Isotope::O21 => None,
            Isotope::O22 => None,
            Isotope::O23 => None,
            Isotope::O24 => None,
            Isotope::O25 => None,
            Isotope::O26 => None,
            Isotope::O27 => None,
            Isotope::O28 => None,
            Isotope::F13 => None,
            Isotope::F14 => None,
            Isotope::F15 => None,
            Isotope::F16 => None,
            Isotope::F17 => None,
            Isotope::F18 => None,
            Isotope::F19 => Some(100.0),
            Isotope::F20 => None,
            Isotope::F21 => None,
            Isotope::F22 => None,
            Isotope::F23 => None,
            Isotope::F24 => None,
            Isotope::F25 => None,
            Isotope::F26 => None,
            Isotope::F27 => None,
            Isotope::F28 => None,
            Isotope::F29 => None,
            Isotope::F30 => None,
            Isotope::F31 => None,
            Isotope::Ne15 => None,
            Isotope::Ne16 => None,
            Isotope::Ne17 => None,
            Isotope::Ne18 => None,
            Isotope::Ne19 => None,
            Isotope::Ne20 => Some(90.48),
            Isotope::Ne21 => Some(0.27),
            Isotope::Ne22 => Some(9.25),
            Isotope::Ne23 => None,
            Isotope::Ne24 => None,
            Isotope::Ne25 => None,
            Isotope::Ne26 => None,
            Isotope::Ne27 => None,
            Isotope::Ne28 => None,
            Isotope::Ne29 => None,
            Isotope::Ne30 => None,
            Isotope::Ne31 => None,
            Isotope::Ne32 => None,
            Isotope::Ne33 => None,
            Isotope::Ne34 => None,
            Isotope::Na17 => None,
            Isotope::Na18 => None,
            Isotope::Na19 => None,
            Isotope::Na20 => None,
            Isotope::Na21 => None,
            Isotope::Na22 => None,
            Isotope::Na23 => Some(100.0),
            Isotope::Na24 => None,
            Isotope::Na25 => None,
            Isotope::Na26 => None,
            Isotope::Na27 => None,
            Isotope::Na28 => None,
            Isotope::Na29 => None,
            Isotope::Na30 => None,
            Isotope::Na31 => None,
            Isotope::Na32 => None,
            Isotope::Na33 => None,
            Isotope::Na34 => None,
            Isotope::Na35 => None,
            Isotope::Na36 => None,
            Isotope::Na37 => None,
            Isotope::Na38 => None,
            Isotope::Na39 => None,
            Isotope::Mg19 => None,
            Isotope::Mg20 => None,
            Isotope::Mg21 => None,
            Isotope::Mg22 => None,
            Isotope::Mg23 => None,
            Isotope::Mg24 => Some(78.965),
            Isotope::Mg25 => Some(10.011),
            Isotope::Mg26 => Some(11.025),
            Isotope::Mg27 => None,
            Isotope::Mg28 => None,
            Isotope::Mg29 => None,
            Isotope::Mg30 => None,
            Isotope::Mg31 => None,
            Isotope::Mg32 => None,
            Isotope::Mg33 => None,
            Isotope::Mg34 => None,
            Isotope::Mg35 => None,
            Isotope::Mg36 => None,
            Isotope::Mg37 => None,
            Isotope::Mg38 => None,
            Isotope::Mg39 => None,
            Isotope::Mg40 => None,
            Isotope::Mg41 => None,
            Isotope::Al21 => None,
            Isotope::Al22 => None,
            Isotope::Al23 => None,
            Isotope::Al24 => None,
            Isotope::Al25 => None,
            Isotope::Al26 => None,
            Isotope::Al27 => Some(100.0),
            Isotope::Al28 => None,
            Isotope::Al29 => None,
            Isotope::Al30 => None,
            Isotope::Al31 => None,
            Isotope::Al32 => None,
            Isotope::Al33 => None,
            Isotope::Al34 => None,
            Isotope::Al35 => None,
            Isotope::Al36 => None,
            Isotope::Al37 => None,
            Isotope::Al38 => None,
            Isotope::Al39 => None,
            Isotope::Al40 => None,
            Isotope::Al41 => None,
            Isotope::Al42 => None,
            Isotope::Al43 => None,
            Isotope::Si22 => None,
            Isotope::Si23 => None,
            Isotope::Si24 => None,
            Isotope::Si25 => None,
            Isotope::Si26 => None,
            Isotope::Si27 => None,
            Isotope::Si28 => Some(92.2545),
            Isotope::Si29 => Some(4.672),
            Isotope::Si30 => Some(3.0735),
            Isotope::Si31 => None,
            Isotope::Si32 => None,
            Isotope::Si33 => None,
            Isotope::Si34 => None,
            Isotope::Si35 => None,
            Isotope::Si36 => None,
            Isotope::Si37 => None,
            Isotope::Si38 => None,
            Isotope::Si39 => None,
            Isotope::Si40 => None,
            Isotope::Si41 => None,
            Isotope::Si42 => None,
            Isotope::Si43 => None,
            Isotope::Si44 => None,
            Isotope::Si45 => None,
            Isotope::P24 => None,
            Isotope::P25 => None,
            Isotope::P26 => None,
            Isotope::P27 => None,
            Isotope::P28 => None,
            Isotope::P29 => None,
            Isotope::P30 => None,
            Isotope::P31 => Some(100.0),
            Isotope::P32 => None,
            Isotope::P33 => None,
            Isotope::P34 => None,
            Isotope::P35 => None,
            Isotope::P36 => None,
            Isotope::P37 => None,
            Isotope::P38 => None,
            Isotope::P39 => None,
            Isotope::P40 => None,
            Isotope::P41 => None,
            Isotope::P42 => None,
            Isotope::P43 => None,
            Isotope::P44 => None,
            Isotope::P45 => None,
            Isotope::P46 => None,
            Isotope::P47 => None,
            Isotope::S26 => None,
            Isotope::S27 => None,
            Isotope::S28 => None,
            Isotope::S29 => None,
            Isotope::S30 => None,
            Isotope::S31 => None,
            Isotope::S32 => Some(94.85),
            Isotope::S33 => Some(0.763),
            Isotope::S34 => Some(4.365),
            Isotope::S35 => None,
            Isotope::S36 => Some(0.0158),
            Isotope::S37 => None,
            Isotope::S38 => None,
            Isotope::S39 => None,
            Isotope::S40 => None,
            Isotope::S41 => None,
            Isotope::S42 => None,
            Isotope::S43 => None,
            Isotope::S44 => None,
            Isotope::S45 => None,
            Isotope::S46 => None,
            Isotope::S47 => None,
            Isotope::S48 => None,
            Isotope::S49 => None,
            Isotope::Cl28 => None,
            Isotope::Cl29 => None,
            Isotope::Cl30 => None,
            Isotope::Cl31 => None,
            Isotope::Cl32 => None,
            Isotope::Cl33 => None,
            Isotope::Cl34 => None,
            Isotope::Cl35 => Some(75.8),
            Isotope::Cl36 => None,
            Isotope::Cl37 => Some(24.2),
            Isotope::Cl38 => None,
            Isotope::Cl39 => None,
            Isotope::Cl40 => None,
            Isotope::Cl41 => None,
            Isotope::Cl42 => None,
            Isotope::Cl43 => None,
            Isotope::Cl44 => None,
            Isotope::Cl45 => None,
            Isotope::Cl46 => None,
            Isotope::Cl47 => None,
            Isotope::Cl48 => None,
            Isotope::Cl49 => None,
            Isotope::Cl50 => None,
            Isotope::Cl51 => None,
            Isotope::Cl52 => None,
            Isotope::Ar29 => None,
            Isotope::Ar30 => None,
            Isotope::Ar31 => None,
            Isotope::Ar32 => None,
            Isotope::Ar33 => None,
            Isotope::Ar34 => None,
            Isotope::Ar35 => None,
            Isotope::Ar36 => Some(0.3336),
            Isotope::Ar37 => None,
            Isotope::Ar38 => Some(0.0629),
            Isotope::Ar39 => None,
            Isotope::Ar40 => Some(99.6035),
            Isotope::Ar41 => None,
            Isotope::Ar42 => None,
            Isotope::Ar43 => None,
            Isotope::Ar44 => None,
            Isotope::Ar45 => None,
            Isotope::Ar46 => None,
            Isotope::Ar47 => None,
            Isotope::Ar48 => None,
            Isotope::Ar49 => None,
            Isotope::Ar50 => None,
            Isotope::Ar51 => None,
            Isotope::Ar52 => None,
            Isotope::Ar53 => None,
            Isotope::Ar54 => None,
            Isotope::K31 => None,
            Isotope::K32 => None,
            Isotope::K33 => None,
            Isotope::K34 => None,
            Isotope::K35 => None,
            Isotope::K36 => None,
            Isotope::K37 => None,
            Isotope::K38 => None,
            Isotope::K39 => Some(93.2581),
            Isotope::K40 => Some(0.0117),
            Isotope::K41 => Some(6.7302),
            Isotope::K42 => None,
            Isotope::K43 => None,
            Isotope::K44 => None,
            Isotope::K45 => None,
            Isotope::K46 => None,
            Isotope::K47 => None,
            Isotope::K48 => None,
            Isotope::K49 => None,
            Isotope::K50 => None,
            Isotope::K51 => None,
            Isotope::K52 => None,
            Isotope::K53 => None,
            Isotope::K54 => None,
            Isotope::K55 => None,
            Isotope::K56 => None,
            Isotope::K57 => None,
            Isotope::K58 => None,
            Isotope::K59 => None,
            Isotope::Ca33 => None,
            Isotope::Ca34 => None,
            Isotope::Ca35 => None,
            Isotope::Ca36 => None,
            Isotope::Ca37 => None,
            Isotope::Ca38 => None,
            Isotope::Ca39 => None,
            Isotope::Ca40 => Some(96.941),
            Isotope::Ca41 => None,
            Isotope::Ca42 => Some(0.647),
            Isotope::Ca43 => Some(0.135),
            Isotope::Ca44 => Some(2.086),
            Isotope::Ca45 => None,
            Isotope::Ca46 => Some(0.004),
            Isotope::Ca47 => None,
            Isotope::Ca48 => Some(0.187),
            Isotope::Ca49 => None,
            Isotope::Ca50 => None,
            Isotope::Ca51 => None,
            Isotope::Ca52 => None,
            Isotope::Ca53 => None,
            Isotope::Ca54 => None,
            Isotope::Ca55 => None,
            Isotope::Ca56 => None,
            Isotope::Ca57 => None,
            Isotope::Ca58 => None,
            Isotope::Ca59 => None,
            Isotope::Ca60 => None,
            Isotope::Ca61 => None,
            Isotope::Sc35 => None,
            Isotope::Sc36 => None,
            Isotope::Sc37 => None,
            Isotope::Sc38 => None,
            Isotope::Sc39 => None,
            Isotope::Sc40 => None,
            Isotope::Sc41 => None,
            Isotope::Sc42 => None,
            Isotope::Sc43 => None,
            Isotope::Sc44 => None,
            Isotope::Sc45 => Some(100.0),
            Isotope::Sc46 => None,
            Isotope::Sc47 => None,
            Isotope::Sc48 => None,
            Isotope::Sc49 => None,
            Isotope::Sc50 => None,
            Isotope::Sc51 => None,
            Isotope::Sc52 => None,
            Isotope::Sc53 => None,
            Isotope::Sc54 => None,
            Isotope::Sc55 => None,
            Isotope::Sc56 => None,
            Isotope::Sc57 => None,
            Isotope::Sc58 => None,
            Isotope::Sc59 => None,
            Isotope::Sc60 => None,
            Isotope::Sc61 => None,
            Isotope::Sc62 => None,
            Isotope::Sc63 => None,
            Isotope::Ti37 => None,
            Isotope::Ti38 => None,
            Isotope::Ti39 => None,
            Isotope::Ti40 => None,
            Isotope::Ti41 => None,
            Isotope::Ti42 => None,
            Isotope::Ti43 => None,
            Isotope::Ti44 => None,
            Isotope::Ti45 => None,
            Isotope::Ti46 => Some(8.25),
            Isotope::Ti47 => Some(7.44),
            Isotope::Ti48 => Some(73.72),
            Isotope::Ti49 => Some(5.41),
            Isotope::Ti50 => Some(5.18),
            Isotope::Ti51 => None,
            Isotope::Ti52 => None,
            Isotope::Ti53 => None,
            Isotope::Ti54 => None,
            Isotope::Ti55 => None,
            Isotope::Ti56 => None,
            Isotope::Ti57 => None,
            Isotope::Ti58 => None,
            Isotope::Ti59 => None,
            Isotope::Ti60 => None,
            Isotope::Ti61 => None,
            Isotope::Ti62 => None,
            Isotope::Ti63 => None,
            Isotope::Ti64 => None,
            Isotope::Ti65 => None,
            Isotope::V39 => None,
            Isotope::V40 => None,
            Isotope::V41 => None,
            Isotope::V42 => None,
            Isotope::V43 => None,
            Isotope::V44 => None,
            Isotope::V45 => None,
            Isotope::V46 => None,
            Isotope::V47 => None,
            Isotope::V48 => None,
            Isotope::V49 => None,
            Isotope::V50 => Some(0.25),
            Isotope::V51 => Some(99.75),
            Isotope::V52 => None,
            Isotope::V53 => None,
            Isotope::V54 => None,
            Isotope::V55 => None,
            Isotope::V56 => None,
            Isotope::V57 => None,
            Isotope::V58 => None,
            Isotope::V59 => None,
            Isotope::V60 => None,
            Isotope::V61 => None,
            Isotope::V62 => None,
            Isotope::V63 => None,
            Isotope::V64 => None,
            Isotope::V65 => None,
            Isotope::V66 => None,
            Isotope::V67 => None,
            Isotope::Cr41 => None,
            Isotope::Cr42 => None,
            Isotope::Cr43 => None,
            Isotope::Cr44 => None,
            Isotope::Cr45 => None,
            Isotope::Cr46 => None,
            Isotope::Cr47 => None,
            Isotope::Cr48 => None,
            Isotope::Cr49 => None,
            Isotope::Cr50 => Some(4.345),
            Isotope::Cr51 => None,
            Isotope::Cr52 => Some(83.789),
            Isotope::Cr53 => Some(9.501),
            Isotope::Cr54 => Some(2.365),
            Isotope::Cr55 => None,
            Isotope::Cr56 => None,
            Isotope::Cr57 => None,
            Isotope::Cr58 => None,
            Isotope::Cr59 => None,
            Isotope::Cr60 => None,
            Isotope::Cr61 => None,
            Isotope::Cr62 => None,
            Isotope::Cr63 => None,
            Isotope::Cr64 => None,
            Isotope::Cr65 => None,
            Isotope::Cr66 => None,
            Isotope::Cr67 => None,
            Isotope::Cr68 => None,
            Isotope::Cr69 => None,
            Isotope::Cr70 => None,
            Isotope::Mn43 => None,
            Isotope::Mn44 => None,
            Isotope::Mn45 => None,
            Isotope::Mn46 => None,
            Isotope::Mn47 => None,
            Isotope::Mn48 => None,
            Isotope::Mn49 => None,
            Isotope::Mn50 => None,
            Isotope::Mn51 => None,
            Isotope::Mn52 => None,
            Isotope::Mn53 => None,
            Isotope::Mn54 => None,
            Isotope::Mn55 => Some(100.0),
            Isotope::Mn56 => None,
            Isotope::Mn57 => None,
            Isotope::Mn58 => None,
            Isotope::Mn59 => None,
            Isotope::Mn60 => None,
            Isotope::Mn61 => None,
            Isotope::Mn62 => None,
            Isotope::Mn63 => None,
            Isotope::Mn64 => None,
            Isotope::Mn65 => None,
            Isotope::Mn66 => None,
            Isotope::Mn67 => None,
            Isotope::Mn68 => None,
            Isotope::Mn69 => None,
            Isotope::Mn70 => None,
            Isotope::Mn71 => None,
            Isotope::Mn72 => None,
            Isotope::Mn73 => None,
            Isotope::Fe45 => None,
            Isotope::Fe46 => None,
            Isotope::Fe47 => None,
            Isotope::Fe48 => None,
            Isotope::Fe49 => None,
            Isotope::Fe50 => None,
            Isotope::Fe51 => None,
            Isotope::Fe52 => None,
            Isotope::Fe53 => None,
            Isotope::Fe54 => Some(5.845),
            Isotope::Fe55 => None,
            Isotope::Fe56 => Some(91.754),
            Isotope::Fe57 => Some(2.119),
            Isotope::Fe58 => Some(0.282),
            Isotope::Fe59 => None,
            Isotope::Fe60 => None,
            Isotope::Fe61 => None,
            Isotope::Fe62 => None,
            Isotope::Fe63 => None,
            Isotope::Fe64 => None,
            Isotope::Fe65 => None,
            Isotope::Fe66 => None,
            Isotope::Fe67 => None,
            Isotope::Fe68 => None,
            Isotope::Fe69 => None,
            Isotope::Fe70 => None,
            Isotope::Fe71 => None,
            Isotope::Fe72 => None,
            Isotope::Fe73 => None,
            Isotope::Fe74 => None,
            Isotope::Fe75 => None,
            Isotope::Fe76 => None,
            Isotope::Co47 => None,
            Isotope::Co48 => None,
            Isotope::Co49 => None,
            Isotope::Co50 => None,
            Isotope::Co51 => None,
            Isotope::Co52 => None,
            Isotope::Co53 => None,
            Isotope::Co54 => None,
            Isotope::Co55 => None,
            Isotope::Co56 => None,
            Isotope::Co57 => None,
            Isotope::Co58 => None,
            Isotope::Co59 => Some(100.0),
            Isotope::Co60 => None,
            Isotope::Co61 => None,
            Isotope::Co62 => None,
            Isotope::Co63 => None,
            Isotope::Co64 => None,
            Isotope::Co65 => None,
            Isotope::Co66 => None,
            Isotope::Co67 => None,
            Isotope::Co68 => None,
            Isotope::Co69 => None,
            Isotope::Co70 => None,
            Isotope::Co71 => None,
            Isotope::Co72 => None,
            Isotope::Co73 => None,
            Isotope::Co74 => None,
            Isotope::Co75 => None,
            Isotope::Co76 => None,
            Isotope::Co77 => None,
            Isotope::Co78 => None,
            Isotope::Ni48 => None,
            Isotope::Ni49 => None,
            Isotope::Ni50 => None,
            Isotope::Ni51 => None,
            Isotope::Ni52 => None,
            Isotope::Ni53 => None,
            Isotope::Ni54 => None,
            Isotope::Ni55 => None,
            Isotope::Ni56 => None,
            Isotope::Ni57 => None,
            Isotope::Ni58 => Some(68.0769),
            Isotope::Ni59 => None,
            Isotope::Ni60 => Some(26.2231),
            Isotope::Ni61 => Some(1.1399),
            Isotope::Ni62 => Some(3.6345),
            Isotope::Ni63 => None,
            Isotope::Ni64 => Some(0.9256),
            Isotope::Ni65 => None,
            Isotope::Ni66 => None,
            Isotope::Ni67 => None,
            Isotope::Ni68 => None,
            Isotope::Ni69 => None,
            Isotope::Ni70 => None,
            Isotope::Ni71 => None,
            Isotope::Ni72 => None,
            Isotope::Ni73 => None,
            Isotope::Ni74 => None,
            Isotope::Ni75 => None,
            Isotope::Ni76 => None,
            Isotope::Ni77 => None,
            Isotope::Ni78 => None,
            Isotope::Ni79 => None,
            Isotope::Ni80 => None,
            Isotope::Ni81 => None,
            Isotope::Ni82 => None,
            Isotope::Cu52 => None,
            Isotope::Cu53 => None,
            Isotope::Cu54 => None,
            Isotope::Cu55 => None,
            Isotope::Cu56 => None,
            Isotope::Cu57 => None,
            Isotope::Cu58 => None,
            Isotope::Cu59 => None,
            Isotope::Cu60 => None,
            Isotope::Cu61 => None,
            Isotope::Cu62 => None,
            Isotope::Cu63 => Some(69.15),
            Isotope::Cu64 => None,
            Isotope::Cu65 => Some(30.85),
            Isotope::Cu66 => None,
            Isotope::Cu67 => None,
            Isotope::Cu68 => None,
            Isotope::Cu69 => None,
            Isotope::Cu70 => None,
            Isotope::Cu71 => None,
            Isotope::Cu72 => None,
            Isotope::Cu73 => None,
            Isotope::Cu74 => None,
            Isotope::Cu75 => None,
            Isotope::Cu76 => None,
            Isotope::Cu77 => None,
            Isotope::Cu78 => None,
            Isotope::Cu79 => None,
            Isotope::Cu80 => None,
            Isotope::Cu81 => None,
            Isotope::Cu82 => None,
            Isotope::Cu83 => None,
            Isotope::Cu84 => None,
            Isotope::Zn54 => None,
            Isotope::Zn55 => None,
            Isotope::Zn56 => None,
            Isotope::Zn57 => None,
            Isotope::Zn58 => None,
            Isotope::Zn59 => None,
            Isotope::Zn60 => None,
            Isotope::Zn61 => None,
            Isotope::Zn62 => None,
            Isotope::Zn63 => None,
            Isotope::Zn64 => Some(49.17),
            Isotope::Zn65 => None,
            Isotope::Zn66 => Some(27.73),
            Isotope::Zn67 => Some(4.04),
            Isotope::Zn68 => Some(18.45),
            Isotope::Zn69 => None,
            Isotope::Zn70 => Some(0.61),
            Isotope::Zn71 => None,
            Isotope::Zn72 => None,
            Isotope::Zn73 => None,
            Isotope::Zn74 => None,
            Isotope::Zn75 => None,
            Isotope::Zn76 => None,
            Isotope::Zn77 => None,
            Isotope::Zn78 => None,
            Isotope::Zn79 => None,
            Isotope::Zn80 => None,
            Isotope::Zn81 => None,
            Isotope::Zn82 => None,
            Isotope::Zn83 => None,
            Isotope::Zn84 => None,
            Isotope::Zn85 => None,
            Isotope::Zn86 => None,
            Isotope::Ga56 => None,
            Isotope::Ga57 => None,
            Isotope::Ga58 => None,
            Isotope::Ga59 => None,
            Isotope::Ga60 => None,
            Isotope::Ga61 => None,
            Isotope::Ga62 => None,
            Isotope::Ga63 => None,
            Isotope::Ga64 => None,
            Isotope::Ga65 => None,
            Isotope::Ga66 => None,
            Isotope::Ga67 => None,
            Isotope::Ga68 => None,
            Isotope::Ga69 => Some(60.108),
            Isotope::Ga70 => None,
            Isotope::Ga71 => Some(39.892),
            Isotope::Ga72 => None,
            Isotope::Ga73 => None,
            Isotope::Ga74 => None,
            Isotope::Ga75 => None,
            Isotope::Ga76 => None,
            Isotope::Ga77 => None,
            Isotope::Ga78 => None,
            Isotope::Ga79 => None,
            Isotope::Ga80 => None,
            Isotope::Ga81 => None,
            Isotope::Ga82 => None,
            Isotope::Ga83 => None,
            Isotope::Ga84 => None,
            Isotope::Ga85 => None,
            Isotope::Ga86 => None,
            Isotope::Ga87 => None,
            Isotope::Ga88 => None,
            Isotope::Ge58 => None,
            Isotope::Ge59 => None,
            Isotope::Ge60 => None,
            Isotope::Ge61 => None,
            Isotope::Ge62 => None,
            Isotope::Ge63 => None,
            Isotope::Ge64 => None,
            Isotope::Ge65 => None,
            Isotope::Ge66 => None,
            Isotope::Ge67 => None,
            Isotope::Ge68 => None,
            Isotope::Ge69 => None,
            Isotope::Ge70 => Some(20.52),
            Isotope::Ge71 => None,
            Isotope::Ge72 => Some(27.45),
            Isotope::Ge73 => Some(7.76),
            Isotope::Ge74 => Some(36.52),
            Isotope::Ge75 => None,
            Isotope::Ge76 => Some(7.75),
            Isotope::Ge77 => None,
            Isotope::Ge78 => None,
            Isotope::Ge79 => None,
            Isotope::Ge80 => None,
            Isotope::Ge81 => None,
            Isotope::Ge82 => None,
            Isotope::Ge83 => None,
            Isotope::Ge84 => None,
            Isotope::Ge85 => None,
            Isotope::Ge86 => None,
            Isotope::Ge87 => None,
            Isotope::Ge88 => None,
            Isotope::Ge89 => None,
            Isotope::Ge90 => None,
            Isotope::As60 => None,
            Isotope::As61 => None,
            Isotope::As62 => None,
            Isotope::As63 => None,
            Isotope::As64 => None,
            Isotope::As65 => None,
            Isotope::As66 => None,
            Isotope::As67 => None,
            Isotope::As68 => None,
            Isotope::As69 => None,
            Isotope::As70 => None,
            Isotope::As71 => None,
            Isotope::As72 => None,
            Isotope::As73 => None,
            Isotope::As74 => None,
            Isotope::As75 => Some(100.0),
            Isotope::As76 => None,
            Isotope::As77 => None,
            Isotope::As78 => None,
            Isotope::As79 => None,
            Isotope::As80 => None,
            Isotope::As81 => None,
            Isotope::As82 => None,
            Isotope::As83 => None,
            Isotope::As84 => None,
            Isotope::As85 => None,
            Isotope::As86 => None,
            Isotope::As87 => None,
            Isotope::As88 => None,
            Isotope::As89 => None,
            Isotope::As90 => None,
            Isotope::As91 => None,
            Isotope::As92 => None,
            Isotope::Se63 => None,
            Isotope::Se64 => None,
            Isotope::Se65 => None,
            Isotope::Se66 => None,
            Isotope::Se67 => None,
            Isotope::Se68 => None,
            Isotope::Se69 => None,
            Isotope::Se70 => None,
            Isotope::Se71 => None,
            Isotope::Se72 => None,
            Isotope::Se73 => None,
            Isotope::Se74 => Some(0.86),
            Isotope::Se75 => None,
            Isotope::Se76 => Some(9.23),
            Isotope::Se77 => Some(7.6),
            Isotope::Se78 => Some(23.69),
            Isotope::Se79 => None,
            Isotope::Se80 => Some(49.8),
            Isotope::Se81 => None,
            Isotope::Se82 => Some(8.82),
            Isotope::Se83 => None,
            Isotope::Se84 => None,
            Isotope::Se85 => None,
            Isotope::Se86 => None,
            Isotope::Se87 => None,
            Isotope::Se88 => None,
            Isotope::Se89 => None,
            Isotope::Se90 => None,
            Isotope::Se91 => None,
            Isotope::Se92 => None,
            Isotope::Se93 => None,
            Isotope::Se94 => None,
            Isotope::Se95 => None,
            Isotope::Br65 => None,
            Isotope::Br66 => None,
            Isotope::Br67 => None,
            Isotope::Br68 => None,
            Isotope::Br69 => None,
            Isotope::Br70 => None,
            Isotope::Br71 => None,
            Isotope::Br72 => None,
            Isotope::Br73 => None,
            Isotope::Br74 => None,
            Isotope::Br75 => None,
            Isotope::Br76 => None,
            Isotope::Br77 => None,
            Isotope::Br78 => None,
            Isotope::Br79 => Some(50.65),
            Isotope::Br80 => None,
            Isotope::Br81 => Some(49.35),
            Isotope::Br82 => None,
            Isotope::Br83 => None,
            Isotope::Br84 => None,
            Isotope::Br85 => None,
            Isotope::Br86 => None,
            Isotope::Br87 => None,
            Isotope::Br88 => None,
            Isotope::Br89 => None,
            Isotope::Br90 => None,
            Isotope::Br91 => None,
            Isotope::Br92 => None,
            Isotope::Br93 => None,
            Isotope::Br94 => None,
            Isotope::Br95 => None,
            Isotope::Br96 => None,
            Isotope::Br97 => None,
            Isotope::Br98 => None,
            Isotope::Kr67 => None,
            Isotope::Kr68 => None,
            Isotope::Kr69 => None,
            Isotope::Kr70 => None,
            Isotope::Kr71 => None,
            Isotope::Kr72 => None,
            Isotope::Kr73 => None,
            Isotope::Kr74 => None,
            Isotope::Kr75 => None,
            Isotope::Kr76 => None,
            Isotope::Kr77 => None,
            Isotope::Kr78 => Some(0.355),
            Isotope::Kr79 => None,
            Isotope::Kr80 => Some(2.286),
            Isotope::Kr81 => None,
            Isotope::Kr82 => Some(11.593),
            Isotope::Kr83 => Some(11.5),
            Isotope::Kr84 => Some(56.987),
            Isotope::Kr85 => None,
            Isotope::Kr86 => Some(17.279),
            Isotope::Kr87 => None,
            Isotope::Kr88 => None,
            Isotope::Kr89 => None,
            Isotope::Kr90 => None,
            Isotope::Kr91 => None,
            Isotope::Kr92 => None,
            Isotope::Kr93 => None,
            Isotope::Kr94 => None,
            Isotope::Kr95 => None,
            Isotope::Kr96 => None,
            Isotope::Kr97 => None,
            Isotope::Kr98 => None,
            Isotope::Kr99 => None,
            Isotope::Kr100 => None,
            Isotope::Kr101 => None,
            Isotope::Rb71 => None,
            Isotope::Rb72 => None,
            Isotope::Rb73 => None,
            Isotope::Rb74 => None,
            Isotope::Rb75 => None,
            Isotope::Rb76 => None,
            Isotope::Rb77 => None,
            Isotope::Rb78 => None,
            Isotope::Rb79 => None,
            Isotope::Rb80 => None,
            Isotope::Rb81 => None,
            Isotope::Rb82 => None,
            Isotope::Rb83 => None,
            Isotope::Rb84 => None,
            Isotope::Rb85 => Some(72.17),
            Isotope::Rb86 => None,
            Isotope::Rb87 => Some(27.83),
            Isotope::Rb88 => None,
            Isotope::Rb89 => None,
            Isotope::Rb90 => None,
            Isotope::Rb91 => None,
            Isotope::Rb92 => None,
            Isotope::Rb93 => None,
            Isotope::Rb94 => None,
            Isotope::Rb95 => None,
            Isotope::Rb96 => None,
            Isotope::Rb97 => None,
            Isotope::Rb98 => None,
            Isotope::Rb99 => None,
            Isotope::Rb100 => None,
            Isotope::Rb101 => None,
            Isotope::Rb102 => None,
            Isotope::Rb103 => None,
            Isotope::Rb104 => None,
            Isotope::Sr73 => None,
            Isotope::Sr74 => None,
            Isotope::Sr75 => None,
            Isotope::Sr76 => None,
            Isotope::Sr77 => None,
            Isotope::Sr78 => None,
            Isotope::Sr79 => None,
            Isotope::Sr80 => None,
            Isotope::Sr81 => None,
            Isotope::Sr82 => None,
            Isotope::Sr83 => None,
            Isotope::Sr84 => Some(0.56),
            Isotope::Sr85 => None,
            Isotope::Sr86 => Some(9.86),
            Isotope::Sr87 => Some(7.0),
            Isotope::Sr88 => Some(82.58),
            Isotope::Sr89 => None,
            Isotope::Sr90 => None,
            Isotope::Sr91 => None,
            Isotope::Sr92 => None,
            Isotope::Sr93 => None,
            Isotope::Sr94 => None,
            Isotope::Sr95 => None,
            Isotope::Sr96 => None,
            Isotope::Sr97 => None,
            Isotope::Sr98 => None,
            Isotope::Sr99 => None,
            Isotope::Sr100 => None,
            Isotope::Sr101 => None,
            Isotope::Sr102 => None,
            Isotope::Sr103 => None,
            Isotope::Sr104 => None,
            Isotope::Sr105 => None,
            Isotope::Sr106 => None,
            Isotope::Sr107 => None,
            Isotope::Y75 => None,
            Isotope::Y76 => None,
            Isotope::Y77 => None,
            Isotope::Y78 => None,
            Isotope::Y79 => None,
            Isotope::Y80 => None,
            Isotope::Y81 => None,
            Isotope::Y82 => None,
            Isotope::Y83 => None,
            Isotope::Y84 => None,
            Isotope::Y85 => None,
            Isotope::Y86 => None,
            Isotope::Y87 => None,
            Isotope::Y88 => None,
            Isotope::Y89 => Some(100.0),
            Isotope::Y90 => None,
            Isotope::Y91 => None,
            Isotope::Y92 => None,
            Isotope::Y93 => None,
            Isotope::Y94 => None,
            Isotope::Y95 => None,
            Isotope::Y96 => None,
            Isotope::Y97 => None,
            Isotope::Y98 => None,
            Isotope::Y99 => None,
            Isotope::Y100 => None,
            Isotope::Y101 => None,
            Isotope::Y102 => None,
            Isotope::Y103 => None,
            Isotope::Y104 => None,
            Isotope::Y105 => None,
            Isotope::Y106 => None,
            Isotope::Y107 => None,
            Isotope::Y108 => None,
            Isotope::Y109 => None,
            Isotope::Zr77 => None,
            Isotope::Zr78 => None,
            Isotope::Zr79 => None,
            Isotope::Zr80 => None,
            Isotope::Zr81 => None,
            Isotope::Zr82 => None,
            Isotope::Zr83 => None,
            Isotope::Zr84 => None,
            Isotope::Zr85 => None,
            Isotope::Zr86 => None,
            Isotope::Zr87 => None,
            Isotope::Zr88 => None,
            Isotope::Zr89 => None,
            Isotope::Zr90 => Some(51.45),
            Isotope::Zr91 => Some(11.22),
            Isotope::Zr92 => Some(17.15),
            Isotope::Zr93 => None,
            Isotope::Zr94 => Some(17.38),
            Isotope::Zr95 => None,
            Isotope::Zr96 => Some(2.8),
            Isotope::Zr97 => None,
            Isotope::Zr98 => None,
            Isotope::Zr99 => None,
            Isotope::Zr100 => None,
            Isotope::Zr101 => None,
            Isotope::Zr102 => None,
            Isotope::Zr103 => None,
            Isotope::Zr104 => None,
            Isotope::Zr105 => None,
            Isotope::Zr106 => None,
            Isotope::Zr107 => None,
            Isotope::Zr108 => None,
            Isotope::Zr109 => None,
            Isotope::Zr110 => None,
            Isotope::Zr111 => None,
            Isotope::Zr112 => None,
            Isotope::Zr113 => None,
            Isotope::Nb79 => None,
            Isotope::Nb80 => None,
            Isotope::Nb81 => None,
            Isotope::Nb82 => None,
            Isotope::Nb83 => None,
            Isotope::Nb84 => None,
            Isotope::Nb85 => None,
            Isotope::Nb86 => None,
            Isotope::Nb87 => None,
            Isotope::Nb88 => None,
            Isotope::Nb89 => None,
            Isotope::Nb90 => None,
            Isotope::Nb91 => None,
            Isotope::Nb92 => None,
            Isotope::Nb93 => Some(100.0),
            Isotope::Nb94 => None,
            Isotope::Nb95 => None,
            Isotope::Nb96 => None,
            Isotope::Nb97 => None,
            Isotope::Nb98 => None,
            Isotope::Nb99 => None,
            Isotope::Nb100 => None,
            Isotope::Nb101 => None,
            Isotope::Nb102 => None,
            Isotope::Nb103 => None,
            Isotope::Nb104 => None,
            Isotope::Nb105 => None,
            Isotope::Nb106 => None,
            Isotope::Nb107 => None,
            Isotope::Nb108 => None,
            Isotope::Nb109 => None,
            Isotope::Nb110 => None,
            Isotope::Nb111 => None,
            Isotope::Nb112 => None,
            Isotope::Nb113 => None,
            Isotope::Nb114 => None,
            Isotope::Nb115 => None,
            Isotope::Nb116 => None,
            Isotope::Mo81 => None,
            Isotope::Mo82 => None,
            Isotope::Mo83 => None,
            Isotope::Mo84 => None,
            Isotope::Mo85 => None,
            Isotope::Mo86 => None,
            Isotope::Mo87 => None,
            Isotope::Mo88 => None,
            Isotope::Mo89 => None,
            Isotope::Mo90 => None,
            Isotope::Mo91 => None,
            Isotope::Mo92 => Some(14.649),
            Isotope::Mo93 => None,
            Isotope::Mo94 => Some(9.187),
            Isotope::Mo95 => Some(15.873),
            Isotope::Mo96 => Some(16.673),
            Isotope::Mo97 => Some(9.582),
            Isotope::Mo98 => Some(24.292),
            Isotope::Mo99 => None,
            Isotope::Mo100 => Some(9.744),
            Isotope::Mo101 => None,
            Isotope::Mo102 => None,
            Isotope::Mo103 => None,
            Isotope::Mo104 => None,
            Isotope::Mo105 => None,
            Isotope::Mo106 => None,
            Isotope::Mo107 => None,
            Isotope::Mo108 => None,
            Isotope::Mo109 => None,
            Isotope::Mo110 => None,
            Isotope::Mo111 => None,
            Isotope::Mo112 => None,
            Isotope::Mo113 => None,
            Isotope::Mo114 => None,
            Isotope::Mo115 => None,
            Isotope::Mo116 => None,
            Isotope::Mo117 => None,
            Isotope::Mo118 => None,
            Isotope::Mo119 => None,
            Isotope::Tc83 => None,
            Isotope::Tc84 => None,
            Isotope::Tc85 => None,
            Isotope::Tc86 => None,
            Isotope::Tc87 => None,
            Isotope::Tc88 => None,
            Isotope::Tc89 => None,
            Isotope::Tc90 => None,
            Isotope::Tc91 => None,
            Isotope::Tc92 => None,
            Isotope::Tc93 => None,
            Isotope::Tc94 => None,
            Isotope::Tc95 => None,
            Isotope::Tc96 => None,
            Isotope::Tc97 => None,
            Isotope::Tc98 => None,
            Isotope::Tc99 => None,
            Isotope::Tc100 => None,
            Isotope::Tc101 => None,
            Isotope::Tc102 => None,
            Isotope::Tc103 => None,
            Isotope::Tc104 => None,
            Isotope::Tc105 => None,
            Isotope::Tc106 => None,
            Isotope::Tc107 => None,
            Isotope::Tc108 => None,
            Isotope::Tc109 => None,
            Isotope::Tc110 => None,
            Isotope::Tc111 => None,
            Isotope::Tc112 => None,
            Isotope::Tc113 => None,
            Isotope::Tc114 => None,
            Isotope::Tc115 => None,
            Isotope::Tc116 => None,
            Isotope::Tc117 => None,
            Isotope::Tc118 => None,
            Isotope::Tc119 => None,
            Isotope::Tc120 => None,
            Isotope::Tc121 => None,
            Isotope::Tc122 => None,
            Isotope::Ru85 => None,
            Isotope::Ru86 => None,
            Isotope::Ru87 => None,
            Isotope::Ru88 => None,
            Isotope::Ru89 => None,
            Isotope::Ru90 => None,
            Isotope::Ru91 => None,
            Isotope::Ru92 => None,
            Isotope::Ru93 => None,
            Isotope::Ru94 => None,
            Isotope::Ru95 => None,
            Isotope::Ru96 => Some(5.54),
            Isotope::Ru97 => None,
            Isotope::Ru98 => Some(1.87),
            Isotope::Ru99 => Some(12.76),
            Isotope::Ru100 => Some(12.6),
            Isotope::Ru101 => Some(17.06),
            Isotope::Ru102 => Some(31.55),
            Isotope::Ru103 => None,
            Isotope::Ru104 => Some(18.62),
            Isotope::Ru105 => None,
            Isotope::Ru106 => None,
            Isotope::Ru107 => None,
            Isotope::Ru108 => None,
            Isotope::Ru109 => None,
            Isotope::Ru110 => None,
            Isotope::Ru111 => None,
            Isotope::Ru112 => None,
            Isotope::Ru113 => None,
            Isotope::Ru114 => None,
            Isotope::Ru115 => None,
            Isotope::Ru116 => None,
            Isotope::Ru117 => None,
            Isotope::Ru118 => None,
            Isotope::Ru119 => None,
            Isotope::Ru120 => None,
            Isotope::Ru121 => None,
            Isotope::Ru122 => None,
            Isotope::Ru123 => None,
            Isotope::Ru124 => None,
            Isotope::Ru125 => None,
            Isotope::Rh88 => None,
            Isotope::Rh89 => None,
            Isotope::Rh90 => None,
            Isotope::Rh91 => None,
            Isotope::Rh92 => None,
            Isotope::Rh93 => None,
            Isotope::Rh94 => None,
            Isotope::Rh95 => None,
            Isotope::Rh96 => None,
            Isotope::Rh97 => None,
            Isotope::Rh98 => None,
            Isotope::Rh99 => None,
            Isotope::Rh100 => None,
            Isotope::Rh101 => None,
            Isotope::Rh102 => None,
            Isotope::Rh103 => Some(100.0),
            Isotope::Rh104 => None,
            Isotope::Rh105 => None,
            Isotope::Rh106 => None,
            Isotope::Rh107 => None,
            Isotope::Rh108 => None,
            Isotope::Rh109 => None,
            Isotope::Rh110 => None,
            Isotope::Rh111 => None,
            Isotope::Rh112 => None,
            Isotope::Rh113 => None,
            Isotope::Rh114 => None,
            Isotope::Rh115 => None,
            Isotope::Rh116 => None,
            Isotope::Rh117 => None,
            Isotope::Rh118 => None,
            Isotope::Rh119 => None,
            Isotope::Rh120 => None,
            Isotope::Rh121 => None,
            Isotope::Rh122 => None,
            Isotope::Rh123 => None,
            Isotope::Rh124 => None,
            Isotope::Rh125 => None,
            Isotope::Rh126 => None,
            Isotope::Rh127 => None,
            Isotope::Rh128 => None,
            Isotope::Pd90 => None,
            Isotope::Pd91 => None,
            Isotope::Pd92 => None,
            Isotope::Pd93 => None,
            Isotope::Pd94 => None,
            Isotope::Pd95 => None,
            Isotope::Pd96 => None,
            Isotope::Pd97 => None,
            Isotope::Pd98 => None,
            Isotope::Pd99 => None,
            Isotope::Pd100 => None,
            Isotope::Pd101 => None,
            Isotope::Pd102 => Some(1.02),
            Isotope::Pd103 => None,
            Isotope::Pd104 => Some(11.14),
            Isotope::Pd105 => Some(22.33),
            Isotope::Pd106 => Some(27.33),
            Isotope::Pd107 => None,
            Isotope::Pd108 => Some(26.46),
            Isotope::Pd109 => None,
            Isotope::Pd110 => Some(11.72),
            Isotope::Pd111 => None,
            Isotope::Pd112 => None,
            Isotope::Pd113 => None,
            Isotope::Pd114 => None,
            Isotope::Pd115 => None,
            Isotope::Pd116 => None,
            Isotope::Pd117 => None,
            Isotope::Pd118 => None,
            Isotope::Pd119 => None,
            Isotope::Pd120 => None,
            Isotope::Pd121 => None,
            Isotope::Pd122 => None,
            Isotope::Pd123 => None,
            Isotope::Pd124 => None,
            Isotope::Pd125 => None,
            Isotope::Pd126 => None,
            Isotope::Pd127 => None,
            Isotope::Pd128 => None,
            Isotope::Pd129 => None,
            Isotope::Pd130 => None,
            Isotope::Pd131 => None,
            Isotope::Ag92 => None,
            Isotope::Ag93 => None,
            Isotope::Ag94 => None,
            Isotope::Ag95 => None,
            Isotope::Ag96 => None,
            Isotope::Ag97 => None,
            Isotope::Ag98 => None,
            Isotope::Ag99 => None,
            Isotope::Ag100 => None,
            Isotope::Ag101 => None,
            Isotope::Ag102 => None,
            Isotope::Ag103 => None,
            Isotope::Ag104 => None,
            Isotope::Ag105 => None,
            Isotope::Ag106 => None,
            Isotope::Ag107 => Some(51.839),
            Isotope::Ag108 => None,
            Isotope::Ag109 => Some(48.161),
            Isotope::Ag110 => None,
            Isotope::Ag111 => None,
            Isotope::Ag112 => None,
            Isotope::Ag113 => None,
            Isotope::Ag114 => None,
            Isotope::Ag115 => None,
            Isotope::Ag116 => None,
            Isotope::Ag117 => None,
            Isotope::Ag118 => None,
            Isotope::Ag119 => None,
            Isotope::Ag120 => None,
            Isotope::Ag121 => None,
            Isotope::Ag122 => None,
            Isotope::Ag123 => None,
            Isotope::Ag124 => None,
            Isotope::Ag125 => None,
            Isotope::Ag126 => None,
            Isotope::Ag127 => None,
            Isotope::Ag128 => None,
            Isotope::Ag129 => None,
            Isotope::Ag130 => None,
            Isotope::Ag131 => None,
            Isotope::Ag132 => None,
            Isotope::Ag133 => None,
            Isotope::Cd94 => None,
            Isotope::Cd95 => None,
            Isotope::Cd96 => None,
            Isotope::Cd97 => None,
            Isotope::Cd98 => None,
            Isotope::Cd99 => None,
            Isotope::Cd100 => None,
            Isotope::Cd101 => None,
            Isotope::Cd102 => None,
            Isotope::Cd103 => None,
            Isotope::Cd104 => None,
            Isotope::Cd105 => None,
            Isotope::Cd106 => Some(1.245),
            Isotope::Cd107 => None,
            Isotope::Cd108 => Some(0.888),
            Isotope::Cd109 => None,
            Isotope::Cd110 => Some(12.47),
            Isotope::Cd111 => Some(12.795),
            Isotope::Cd112 => Some(24.109),
            Isotope::Cd113 => Some(12.227),
            Isotope::Cd114 => Some(28.754),
            Isotope::Cd115 => None,
            Isotope::Cd116 => Some(7.512),
            Isotope::Cd117 => None,
            Isotope::Cd118 => None,
            Isotope::Cd119 => None,
            Isotope::Cd120 => None,
            Isotope::Cd121 => None,
            Isotope::Cd122 => None,
            Isotope::Cd123 => None,
            Isotope::Cd124 => None,
            Isotope::Cd125 => None,
            Isotope::Cd126 => None,
            Isotope::Cd127 => None,
            Isotope::Cd128 => None,
            Isotope::Cd129 => None,
            Isotope::Cd130 => None,
            Isotope::Cd131 => None,
            Isotope::Cd132 => None,
            Isotope::Cd133 => None,
            Isotope::Cd134 => None,
            Isotope::Cd135 => None,
            Isotope::In96 => None,
            Isotope::In97 => None,
            Isotope::In98 => None,
            Isotope::In99 => None,
            Isotope::In100 => None,
            Isotope::In101 => None,
            Isotope::In102 => None,
            Isotope::In103 => None,
            Isotope::In104 => None,
            Isotope::In105 => None,
            Isotope::In106 => None,
            Isotope::In107 => None,
            Isotope::In108 => None,
            Isotope::In109 => None,
            Isotope::In110 => None,
            Isotope::In111 => None,
            Isotope::In112 => None,
            Isotope::In113 => Some(4.281),
            Isotope::In114 => None,
            Isotope::In115 => Some(95.719),
            Isotope::In116 => None,
            Isotope::In117 => None,
            Isotope::In118 => None,
            Isotope::In119 => None,
            Isotope::In120 => None,
            Isotope::In121 => None,
            Isotope::In122 => None,
            Isotope::In123 => None,
            Isotope::In124 => None,
            Isotope::In125 => None,
            Isotope::In126 => None,
            Isotope::In127 => None,
            Isotope::In128 => None,
            Isotope::In129 => None,
            Isotope::In130 => None,
            Isotope::In131 => None,
            Isotope::In132 => None,
            Isotope::In133 => None,
            Isotope::In134 => None,
            Isotope::In135 => None,
            Isotope::In136 => None,
            Isotope::In137 => None,
            Isotope::Sn99 => None,
            Isotope::Sn100 => None,
            Isotope::Sn101 => None,
            Isotope::Sn102 => None,
            Isotope::Sn103 => None,
            Isotope::Sn104 => None,
            Isotope::Sn105 => None,
            Isotope::Sn106 => None,
            Isotope::Sn107 => None,
            Isotope::Sn108 => None,
            Isotope::Sn109 => None,
            Isotope::Sn110 => None,
            Isotope::Sn111 => None,
            Isotope::Sn112 => Some(0.97),
            Isotope::Sn113 => None,
            Isotope::Sn114 => Some(0.66),
            Isotope::Sn115 => Some(0.34),
            Isotope::Sn116 => Some(14.54),
            Isotope::Sn117 => Some(7.68),
            Isotope::Sn118 => Some(24.22),
            Isotope::Sn119 => Some(8.59),
            Isotope::Sn120 => Some(32.58),
            Isotope::Sn121 => None,
            Isotope::Sn122 => Some(4.63),
            Isotope::Sn123 => None,
            Isotope::Sn124 => Some(5.79),
            Isotope::Sn125 => None,
            Isotope::Sn126 => None,
            Isotope::Sn127 => None,
            Isotope::Sn128 => None,
            Isotope::Sn129 => None,
            Isotope::Sn130 => None,
            Isotope::Sn131 => None,
            Isotope::Sn132 => None,
            Isotope::Sn133 => None,
            Isotope::Sn134 => None,
            Isotope::Sn135 => None,
            Isotope::Sn136 => None,
            Isotope::Sn137 => None,
            Isotope::Sn138 => None,
            Isotope::Sn139 => None,
            Isotope::Sn140 => None,
            Isotope::Sb102 => None,
            Isotope::Sb103 => None,
            Isotope::Sb104 => None,
            Isotope::Sb105 => None,
            Isotope::Sb106 => None,
            Isotope::Sb107 => None,
            Isotope::Sb108 => None,
            Isotope::Sb109 => None,
            Isotope::Sb110 => None,
            Isotope::Sb111 => None,
            Isotope::Sb112 => None,
            Isotope::Sb113 => None,
            Isotope::Sb114 => None,
            Isotope::Sb115 => None,
            Isotope::Sb116 => None,
            Isotope::Sb117 => None,
            Isotope::Sb118 => None,
            Isotope::Sb119 => None,
            Isotope::Sb120 => None,
            Isotope::Sb121 => Some(57.21),
            Isotope::Sb122 => None,
            Isotope::Sb123 => Some(42.79),
            Isotope::Sb124 => None,
            Isotope::Sb125 => None,
            Isotope::Sb126 => None,
            Isotope::Sb127 => None,
            Isotope::Sb128 => None,
            Isotope::Sb129 => None,
            Isotope::Sb130 => None,
            Isotope::Sb131 => None,
            Isotope::Sb132 => None,
            Isotope::Sb133 => None,
            Isotope::Sb134 => None,
            Isotope::Sb135 => None,
            Isotope::Sb136 => None,
            Isotope::Sb137 => None,
            Isotope::Sb138 => None,
            Isotope::Sb139 => None,
            Isotope::Sb140 => None,
            Isotope::Sb141 => None,
            Isotope::Sb142 => None,
            Isotope::Te104 => None,
            Isotope::Te105 => None,
            Isotope::Te106 => None,
            Isotope::Te107 => None,
            Isotope::Te108 => None,
            Isotope::Te109 => None,
            Isotope::Te110 => None,
            Isotope::Te111 => None,
            Isotope::Te112 => None,
            Isotope::Te113 => None,
            Isotope::Te114 => None,
            Isotope::Te115 => None,
            Isotope::Te116 => None,
            Isotope::Te117 => None,
            Isotope::Te118 => None,
            Isotope::Te119 => None,
            Isotope::Te120 => Some(0.09),
            Isotope::Te121 => None,
            Isotope::Te122 => Some(2.55),
            Isotope::Te123 => Some(0.89),
            Isotope::Te124 => Some(4.74),
            Isotope::Te125 => Some(7.07),
            Isotope::Te126 => Some(8.84),
            Isotope::Te127 => None,
            Isotope::Te128 => Some(31.74),
            Isotope::Te129 => None,
            Isotope::Te130 => Some(34.08),
            Isotope::Te131 => None,
            Isotope::Te132 => None,
            Isotope::Te133 => None,
            Isotope::Te134 => None,
            Isotope::Te135 => None,
            Isotope::Te136 => None,
            Isotope::Te137 => None,
            Isotope::Te138 => None,
            Isotope::Te139 => None,
            Isotope::Te140 => None,
            Isotope::Te141 => None,
            Isotope::Te142 => None,
            Isotope::Te143 => None,
            Isotope::Te144 => None,
            Isotope::Te145 => None,
            Isotope::I106 => None,
            Isotope::I107 => None,
            Isotope::I108 => None,
            Isotope::I109 => None,
            Isotope::I110 => None,
            Isotope::I111 => None,
            Isotope::I112 => None,
            Isotope::I113 => None,
            Isotope::I114 => None,
            Isotope::I115 => None,
            Isotope::I116 => None,
            Isotope::I117 => None,
            Isotope::I118 => None,
            Isotope::I119 => None,
            Isotope::I120 => None,
            Isotope::I121 => None,
            Isotope::I122 => None,
            Isotope::I123 => None,
            Isotope::I124 => None,
            Isotope::I125 => None,
            Isotope::I126 => None,
            Isotope::I127 => Some(100.0),
            Isotope::I128 => None,
            Isotope::I129 => None,
            Isotope::I130 => None,
            Isotope::I131 => None,
            Isotope::I132 => None,
            Isotope::I133 => None,
            Isotope::I134 => None,
            Isotope::I135 => None,
            Isotope::I136 => None,
            Isotope::I137 => None,
            Isotope::I138 => None,
            Isotope::I139 => None,
            Isotope::I140 => None,
            Isotope::I141 => None,
            Isotope::I142 => None,
            Isotope::I143 => None,
            Isotope::I144 => None,
            Isotope::I145 => None,
            Isotope::I146 => None,
            Isotope::I147 => None,
            Isotope::Xe108 => None,
            Isotope::Xe109 => None,
            Isotope::Xe110 => None,
            Isotope::Xe111 => None,
            Isotope::Xe112 => None,
            Isotope::Xe113 => None,
            Isotope::Xe114 => None,
            Isotope::Xe115 => None,
            Isotope::Xe116 => None,
            Isotope::Xe117 => None,
            Isotope::Xe118 => None,
            Isotope::Xe119 => None,
            Isotope::Xe120 => None,
            Isotope::Xe121 => None,
            Isotope::Xe122 => None,
            Isotope::Xe123 => None,
            Isotope::Xe124 => Some(0.095),
            Isotope::Xe125 => None,
            Isotope::Xe126 => Some(0.089),
            Isotope::Xe127 => None,
            Isotope::Xe128 => Some(1.91),
            Isotope::Xe129 => Some(26.401),
            Isotope::Xe130 => Some(4.071),
            Isotope::Xe131 => Some(21.232),
            Isotope::Xe132 => Some(26.909),
            Isotope::Xe133 => None,
            Isotope::Xe134 => Some(10.436),
            Isotope::Xe135 => None,
            Isotope::Xe136 => Some(8.857),
            Isotope::Xe137 => None,
            Isotope::Xe138 => None,
            Isotope::Xe139 => None,
            Isotope::Xe140 => None,
            Isotope::Xe141 => None,
            Isotope::Xe142 => None,
            Isotope::Xe143 => None,
            Isotope::Xe144 => None,
            Isotope::Xe145 => None,
            Isotope::Xe146 => None,
            Isotope::Xe147 => None,
            Isotope::Xe148 => None,
            Isotope::Xe149 => None,
            Isotope::Xe150 => None,
            Isotope::Cs111 => None,
            Isotope::Cs112 => None,
            Isotope::Cs113 => None,
            Isotope::Cs114 => None,
            Isotope::Cs115 => None,
            Isotope::Cs116 => None,
            Isotope::Cs117 => None,
            Isotope::Cs118 => None,
            Isotope::Cs119 => None,
            Isotope::Cs120 => None,
            Isotope::Cs121 => None,
            Isotope::Cs122 => None,
            Isotope::Cs123 => None,
            Isotope::Cs124 => None,
            Isotope::Cs125 => None,
            Isotope::Cs126 => None,
            Isotope::Cs127 => None,
            Isotope::Cs128 => None,
            Isotope::Cs129 => None,
            Isotope::Cs130 => None,
            Isotope::Cs131 => None,
            Isotope::Cs132 => None,
            Isotope::Cs133 => Some(100.0),
            Isotope::Cs134 => None,
            Isotope::Cs135 => None,
            Isotope::Cs136 => None,
            Isotope::Cs137 => None,
            Isotope::Cs138 => None,
            Isotope::Cs139 => None,
            Isotope::Cs140 => None,
            Isotope::Cs141 => None,
            Isotope::Cs142 => None,
            Isotope::Cs143 => None,
            Isotope::Cs144 => None,
            Isotope::Cs145 => None,
            Isotope::Cs146 => None,
            Isotope::Cs147 => None,
            Isotope::Cs148 => None,
            Isotope::Cs149 => None,
            Isotope::Cs150 => None,
            Isotope::Cs151 => None,
            Isotope::Cs152 => None,
            Isotope::Ba113 => None,
            Isotope::Ba114 => None,
            Isotope::Ba115 => None,
            Isotope::Ba116 => None,
            Isotope::Ba117 => None,
            Isotope::Ba118 => None,
            Isotope::Ba119 => None,
            Isotope::Ba120 => None,
            Isotope::Ba121 => None,
            Isotope::Ba122 => None,
            Isotope::Ba123 => None,
            Isotope::Ba124 => None,
            Isotope::Ba125 => None,
            Isotope::Ba126 => None,
            Isotope::Ba127 => None,
            Isotope::Ba128 => None,
            Isotope::Ba129 => None,
            Isotope::Ba130 => Some(0.11),
            Isotope::Ba131 => None,
            Isotope::Ba132 => Some(0.1),
            Isotope::Ba133 => None,
            Isotope::Ba134 => Some(2.42),
            Isotope::Ba135 => Some(6.59),
            Isotope::Ba136 => Some(7.85),
            Isotope::Ba137 => Some(11.23),
            Isotope::Ba138 => Some(71.7),
            Isotope::Ba139 => None,
            Isotope::Ba140 => None,
            Isotope::Ba141 => None,
            Isotope::Ba142 => None,
            Isotope::Ba143 => None,
            Isotope::Ba144 => None,
            Isotope::Ba145 => None,
            Isotope::Ba146 => None,
            Isotope::Ba147 => None,
            Isotope::Ba148 => None,
            Isotope::Ba149 => None,
            Isotope::Ba150 => None,
            Isotope::Ba151 => None,
            Isotope::Ba152 => None,
            Isotope::Ba153 => None,
            Isotope::Ba154 => None,
            Isotope::La116 => None,
            Isotope::La117 => None,
            Isotope::La118 => None,
            Isotope::La119 => None,
            Isotope::La120 => None,
            Isotope::La121 => None,
            Isotope::La122 => None,
            Isotope::La123 => None,
            Isotope::La124 => None,
            Isotope::La125 => None,
            Isotope::La126 => None,
            Isotope::La127 => None,
            Isotope::La128 => None,
            Isotope::La129 => None,
            Isotope::La130 => None,
            Isotope::La131 => None,
            Isotope::La132 => None,
            Isotope::La133 => None,
            Isotope::La134 => None,
            Isotope::La135 => None,
            Isotope::La136 => None,
            Isotope::La137 => None,
            Isotope::La138 => Some(0.08881),
            Isotope::La139 => Some(99.91119),
            Isotope::La140 => None,
            Isotope::La141 => None,
            Isotope::La142 => None,
            Isotope::La143 => None,
            Isotope::La144 => None,
            Isotope::La145 => None,
            Isotope::La146 => None,
            Isotope::La147 => None,
            Isotope::La148 => None,
            Isotope::La149 => None,
            Isotope::La150 => None,
            Isotope::La151 => None,
            Isotope::La152 => None,
            Isotope::La153 => None,
            Isotope::La154 => None,
            Isotope::La155 => None,
            Isotope::La156 => None,
            Isotope::La157 => None,
            Isotope::Ce119 => None,
            Isotope::Ce120 => None,
            Isotope::Ce121 => None,
            Isotope::Ce122 => None,
            Isotope::Ce123 => None,
            Isotope::Ce124 => None,
            Isotope::Ce125 => None,
            Isotope::Ce126 => None,
            Isotope::Ce127 => None,
            Isotope::Ce128 => None,
            Isotope::Ce129 => None,
            Isotope::Ce130 => None,
            Isotope::Ce131 => None,
            Isotope::Ce132 => None,
            Isotope::Ce133 => None,
            Isotope::Ce134 => None,
            Isotope::Ce135 => None,
            Isotope::Ce136 => Some(0.186),
            Isotope::Ce137 => None,
            Isotope::Ce138 => Some(0.251),
            Isotope::Ce139 => None,
            Isotope::Ce140 => Some(88.449),
            Isotope::Ce141 => None,
            Isotope::Ce142 => Some(11.114),
            Isotope::Ce143 => None,
            Isotope::Ce144 => None,
            Isotope::Ce145 => None,
            Isotope::Ce146 => None,
            Isotope::Ce147 => None,
            Isotope::Ce148 => None,
            Isotope::Ce149 => None,
            Isotope::Ce150 => None,
            Isotope::Ce151 => None,
            Isotope::Ce152 => None,
            Isotope::Ce153 => None,
            Isotope::Ce154 => None,
            Isotope::Ce155 => None,
            Isotope::Ce156 => None,
            Isotope::Ce157 => None,
            Isotope::Ce158 => None,
            Isotope::Ce159 => None,
            Isotope::Pr121 => None,
            Isotope::Pr122 => None,
            Isotope::Pr123 => None,
            Isotope::Pr124 => None,
            Isotope::Pr125 => None,
            Isotope::Pr126 => None,
            Isotope::Pr127 => None,
            Isotope::Pr128 => None,
            Isotope::Pr129 => None,
            Isotope::Pr130 => None,
            Isotope::Pr131 => None,
            Isotope::Pr132 => None,
            Isotope::Pr133 => None,
            Isotope::Pr134 => None,
            Isotope::Pr135 => None,
            Isotope::Pr136 => None,
            Isotope::Pr137 => None,
            Isotope::Pr138 => None,
            Isotope::Pr139 => None,
            Isotope::Pr140 => None,
            Isotope::Pr141 => Some(100.0),
            Isotope::Pr142 => None,
            Isotope::Pr143 => None,
            Isotope::Pr144 => None,
            Isotope::Pr145 => None,
            Isotope::Pr146 => None,
            Isotope::Pr147 => None,
            Isotope::Pr148 => None,
            Isotope::Pr149 => None,
            Isotope::Pr150 => None,
            Isotope::Pr151 => None,
            Isotope::Pr152 => None,
            Isotope::Pr153 => None,
            Isotope::Pr154 => None,
            Isotope::Pr155 => None,
            Isotope::Pr156 => None,
            Isotope::Pr157 => None,
            Isotope::Pr158 => None,
            Isotope::Pr159 => None,
            Isotope::Pr160 => None,
            Isotope::Pr161 => None,
            Isotope::Nd124 => None,
            Isotope::Nd125 => None,
            Isotope::Nd126 => None,
            Isotope::Nd127 => None,
            Isotope::Nd128 => None,
            Isotope::Nd129 => None,
            Isotope::Nd130 => None,
            Isotope::Nd131 => None,
            Isotope::Nd132 => None,
            Isotope::Nd133 => None,
            Isotope::Nd134 => None,
            Isotope::Nd135 => None,
            Isotope::Nd136 => None,
            Isotope::Nd137 => None,
            Isotope::Nd138 => None,
            Isotope::Nd139 => None,
            Isotope::Nd140 => None,
            Isotope::Nd141 => None,
            Isotope::Nd142 => Some(27.153),
            Isotope::Nd143 => Some(12.173),
            Isotope::Nd144 => Some(23.798),
            Isotope::Nd145 => Some(8.293),
            Isotope::Nd146 => Some(17.189),
            Isotope::Nd147 => None,
            Isotope::Nd148 => Some(5.756),
            Isotope::Nd149 => None,
            Isotope::Nd150 => Some(5.638),
            Isotope::Nd151 => None,
            Isotope::Nd152 => None,
            Isotope::Nd153 => None,
            Isotope::Nd154 => None,
            Isotope::Nd155 => None,
            Isotope::Nd156 => None,
            Isotope::Nd157 => None,
            Isotope::Nd158 => None,
            Isotope::Nd159 => None,
            Isotope::Nd160 => None,
            Isotope::Nd161 => None,
            Isotope::Nd162 => None,
            Isotope::Nd163 => None,
            Isotope::Pm126 => None,
            Isotope::Pm127 => None,
            Isotope::Pm128 => None,
            Isotope::Pm129 => None,
            Isotope::Pm130 => None,
            Isotope::Pm131 => None,
            Isotope::Pm132 => None,
            Isotope::Pm133 => None,
            Isotope::Pm134 => None,
            Isotope::Pm135 => None,
            Isotope::Pm136 => None,
            Isotope::Pm137 => None,
            Isotope::Pm138 => None,
            Isotope::Pm139 => None,
            Isotope::Pm140 => None,
            Isotope::Pm141 => None,
            Isotope::Pm142 => None,
            Isotope::Pm143 => None,
            Isotope::Pm144 => None,
            Isotope::Pm145 => None,
            Isotope::Pm146 => None,
            Isotope::Pm147 => None,
            Isotope::Pm148 => None,
            Isotope::Pm149 => None,
            Isotope::Pm150 => None,
            Isotope::Pm151 => None,
            Isotope::Pm152 => None,
            Isotope::Pm153 => None,
            Isotope::Pm154 => None,
            Isotope::Pm155 => None,
            Isotope::Pm156 => None,
            Isotope::Pm157 => None,
            Isotope::Pm158 => None,
            Isotope::Pm159 => None,
            Isotope::Pm160 => None,
            Isotope::Pm161 => None,
            Isotope::Pm162 => None,
            Isotope::Pm163 => None,
            Isotope::Pm164 => None,
            Isotope::Pm165 => None,
            Isotope::Sm128 => None,
            Isotope::Sm129 => None,
            Isotope::Sm130 => None,
            Isotope::Sm131 => None,
            Isotope::Sm132 => None,
            Isotope::Sm133 => None,
            Isotope::Sm134 => None,
            Isotope::Sm135 => None,
            Isotope::Sm136 => None,
            Isotope::Sm137 => None,
            Isotope::Sm138 => None,
            Isotope::Sm139 => None,
            Isotope::Sm140 => None,
            Isotope::Sm141 => None,
            Isotope::Sm142 => None,
            Isotope::Sm143 => None,
            Isotope::Sm144 => Some(3.08),
            Isotope::Sm145 => None,
            Isotope::Sm146 => None,
            Isotope::Sm147 => Some(15.0),
            Isotope::Sm148 => Some(11.25),
            Isotope::Sm149 => Some(13.82),
            Isotope::Sm150 => Some(7.37),
            Isotope::Sm151 => None,
            Isotope::Sm152 => Some(26.74),
            Isotope::Sm153 => None,
            Isotope::Sm154 => Some(22.74),
            Isotope::Sm155 => None,
            Isotope::Sm156 => None,
            Isotope::Sm157 => None,
            Isotope::Sm158 => None,
            Isotope::Sm159 => None,
            Isotope::Sm160 => None,
            Isotope::Sm161 => None,
            Isotope::Sm162 => None,
            Isotope::Sm163 => None,
            Isotope::Sm164 => None,
            Isotope::Sm165 => None,
            Isotope::Sm166 => None,
            Isotope::Sm167 => None,
            Isotope::Sm168 => None,
            Isotope::Eu130 => None,
            Isotope::Eu131 => None,
            Isotope::Eu132 => None,
            Isotope::Eu133 => None,
            Isotope::Eu134 => None,
            Isotope::Eu135 => None,
            Isotope::Eu136 => None,
            Isotope::Eu137 => None,
            Isotope::Eu138 => None,
            Isotope::Eu139 => None,
            Isotope::Eu140 => None,
            Isotope::Eu141 => None,
            Isotope::Eu142 => None,
            Isotope::Eu143 => None,
            Isotope::Eu144 => None,
            Isotope::Eu145 => None,
            Isotope::Eu146 => None,
            Isotope::Eu147 => None,
            Isotope::Eu148 => None,
            Isotope::Eu149 => None,
            Isotope::Eu150 => None,
            Isotope::Eu151 => Some(47.81),
            Isotope::Eu152 => None,
            Isotope::Eu153 => Some(52.19),
            Isotope::Eu154 => None,
            Isotope::Eu155 => None,
            Isotope::Eu156 => None,
            Isotope::Eu157 => None,
            Isotope::Eu158 => None,
            Isotope::Eu159 => None,
            Isotope::Eu160 => None,
            Isotope::Eu161 => None,
            Isotope::Eu162 => None,
            Isotope::Eu163 => None,
            Isotope::Eu164 => None,
            Isotope::Eu165 => None,
            Isotope::Eu166 => None,
            Isotope::Eu167 => None,
            Isotope::Eu168 => None,
            Isotope::Eu169 => None,
            Isotope::Eu170 => None,
            Isotope::Gd133 => None,
            Isotope::Gd134 => None,
            Isotope::Gd135 => None,
            Isotope::Gd136 => None,
            Isotope::Gd137 => None,
            Isotope::Gd138 => None,
            Isotope::Gd139 => None,
            Isotope::Gd140 => None,
            Isotope::Gd141 => None,
            Isotope::Gd142 => None,
            Isotope::Gd143 => None,
            Isotope::Gd144 => None,
            Isotope::Gd145 => None,
            Isotope::Gd146 => None,
            Isotope::Gd147 => None,
            Isotope::Gd148 => None,
            Isotope::Gd149 => None,
            Isotope::Gd150 => None,
            Isotope::Gd151 => None,
            Isotope::Gd152 => Some(0.2),
            Isotope::Gd153 => None,
            Isotope::Gd154 => Some(2.18),
            Isotope::Gd155 => Some(14.8),
            Isotope::Gd156 => Some(20.47),
            Isotope::Gd157 => Some(15.65),
            Isotope::Gd158 => Some(24.84),
            Isotope::Gd159 => None,
            Isotope::Gd160 => Some(21.86),
            Isotope::Gd161 => None,
            Isotope::Gd162 => None,
            Isotope::Gd163 => None,
            Isotope::Gd164 => None,
            Isotope::Gd165 => None,
            Isotope::Gd166 => None,
            Isotope::Gd167 => None,
            Isotope::Gd168 => None,
            Isotope::Gd169 => None,
            Isotope::Gd170 => None,
            Isotope::Gd171 => None,
            Isotope::Gd172 => None,
            Isotope::Tb135 => None,
            Isotope::Tb136 => None,
            Isotope::Tb137 => None,
            Isotope::Tb138 => None,
            Isotope::Tb139 => None,
            Isotope::Tb140 => None,
            Isotope::Tb141 => None,
            Isotope::Tb142 => None,
            Isotope::Tb143 => None,
            Isotope::Tb144 => None,
            Isotope::Tb145 => None,
            Isotope::Tb146 => None,
            Isotope::Tb147 => None,
            Isotope::Tb148 => None,
            Isotope::Tb149 => None,
            Isotope::Tb150 => None,
            Isotope::Tb151 => None,
            Isotope::Tb152 => None,
            Isotope::Tb153 => None,
            Isotope::Tb154 => None,
            Isotope::Tb155 => None,
            Isotope::Tb156 => None,
            Isotope::Tb157 => None,
            Isotope::Tb158 => None,
            Isotope::Tb159 => Some(100.0),
            Isotope::Tb160 => None,
            Isotope::Tb161 => None,
            Isotope::Tb162 => None,
            Isotope::Tb163 => None,
            Isotope::Tb164 => None,
            Isotope::Tb165 => None,
            Isotope::Tb166 => None,
            Isotope::Tb167 => None,
            Isotope::Tb168 => None,
            Isotope::Tb169 => None,
            Isotope::Tb170 => None,
            Isotope::Tb171 => None,
            Isotope::Tb172 => None,
            Isotope::Tb173 => None,
            Isotope::Tb174 => None,
            Isotope::Dy138 => None,
            Isotope::Dy139 => None,
            Isotope::Dy140 => None,
            Isotope::Dy141 => None,
            Isotope::Dy142 => None,
            Isotope::Dy143 => None,
            Isotope::Dy144 => None,
            Isotope::Dy145 => None,
            Isotope::Dy146 => None,
            Isotope::Dy147 => None,
            Isotope::Dy148 => None,
            Isotope::Dy149 => None,
            Isotope::Dy150 => None,
            Isotope::Dy151 => None,
            Isotope::Dy152 => None,
            Isotope::Dy153 => None,
            Isotope::Dy154 => None,
            Isotope::Dy155 => None,
            Isotope::Dy156 => Some(0.056),
            Isotope::Dy157 => None,
            Isotope::Dy158 => Some(0.095),
            Isotope::Dy159 => None,
            Isotope::Dy160 => Some(2.329),
            Isotope::Dy161 => Some(18.889),
            Isotope::Dy162 => Some(25.475),
            Isotope::Dy163 => Some(24.896),
            Isotope::Dy164 => Some(28.26),
            Isotope::Dy165 => None,
            Isotope::Dy166 => None,
            Isotope::Dy167 => None,
            Isotope::Dy168 => None,
            Isotope::Dy169 => None,
            Isotope::Dy170 => None,
            Isotope::Dy171 => None,
            Isotope::Dy172 => None,
            Isotope::Dy173 => None,
            Isotope::Dy174 => None,
            Isotope::Dy175 => None,
            Isotope::Dy176 => None,
            Isotope::Ho140 => None,
            Isotope::Ho141 => None,
            Isotope::Ho142 => None,
            Isotope::Ho143 => None,
            Isotope::Ho144 => None,
            Isotope::Ho145 => None,
            Isotope::Ho146 => None,
            Isotope::Ho147 => None,
            Isotope::Ho148 => None,
            Isotope::Ho149 => None,
            Isotope::Ho150 => None,
            Isotope::Ho151 => None,
            Isotope::Ho152 => None,
            Isotope::Ho153 => None,
            Isotope::Ho154 => None,
            Isotope::Ho155 => None,
            Isotope::Ho156 => None,
            Isotope::Ho157 => None,
            Isotope::Ho158 => None,
            Isotope::Ho159 => None,
            Isotope::Ho160 => None,
            Isotope::Ho161 => None,
            Isotope::Ho162 => None,
            Isotope::Ho163 => None,
            Isotope::Ho164 => None,
            Isotope::Ho165 => Some(100.0),
            Isotope::Ho166 => None,
            Isotope::Ho167 => None,
            Isotope::Ho168 => None,
            Isotope::Ho169 => None,
            Isotope::Ho170 => None,
            Isotope::Ho171 => None,
            Isotope::Ho172 => None,
            Isotope::Ho173 => None,
            Isotope::Ho174 => None,
            Isotope::Ho175 => None,
            Isotope::Ho176 => None,
            Isotope::Ho177 => None,
            Isotope::Ho178 => None,
            Isotope::Er142 => None,
            Isotope::Er143 => None,
            Isotope::Er144 => None,
            Isotope::Er145 => None,
            Isotope::Er146 => None,
            Isotope::Er147 => None,
            Isotope::Er148 => None,
            Isotope::Er149 => None,
            Isotope::Er150 => None,
            Isotope::Er151 => None,
            Isotope::Er152 => None,
            Isotope::Er153 => None,
            Isotope::Er154 => None,
            Isotope::Er155 => None,
            Isotope::Er156 => None,
            Isotope::Er157 => None,
            Isotope::Er158 => None,
            Isotope::Er159 => None,
            Isotope::Er160 => None,
            Isotope::Er161 => None,
            Isotope::Er162 => Some(0.139),
            Isotope::Er163 => None,
            Isotope::Er164 => Some(1.601),
            Isotope::Er165 => None,
            Isotope::Er166 => Some(33.503),
            Isotope::Er167 => Some(22.869),
            Isotope::Er168 => Some(26.978),
            Isotope::Er169 => None,
            Isotope::Er170 => Some(14.91),
            Isotope::Er171 => None,
            Isotope::Er172 => None,
            Isotope::Er173 => None,
            Isotope::Er174 => None,
            Isotope::Er175 => None,
            Isotope::Er176 => None,
            Isotope::Er177 => None,
            Isotope::Er178 => None,
            Isotope::Er179 => None,
            Isotope::Er180 => None,
            Isotope::Tm144 => None,
            Isotope::Tm145 => None,
            Isotope::Tm146 => None,
            Isotope::Tm147 => None,
            Isotope::Tm148 => None,
            Isotope::Tm149 => None,
            Isotope::Tm150 => None,
            Isotope::Tm151 => None,
            Isotope::Tm152 => None,
            Isotope::Tm153 => None,
            Isotope::Tm154 => None,
            Isotope::Tm155 => None,
            Isotope::Tm156 => None,
            Isotope::Tm157 => None,
            Isotope::Tm158 => None,
            Isotope::Tm159 => None,
            Isotope::Tm160 => None,
            Isotope::Tm161 => None,
            Isotope::Tm162 => None,
            Isotope::Tm163 => None,
            Isotope::Tm164 => None,
            Isotope::Tm165 => None,
            Isotope::Tm166 => None,
            Isotope::Tm167 => None,
            Isotope::Tm168 => None,
            Isotope::Tm169 => Some(100.0),
            Isotope::Tm170 => None,
            Isotope::Tm171 => None,
            Isotope::Tm172 => None,
            Isotope::Tm173 => None,
            Isotope::Tm174 => None,
            Isotope::Tm175 => None,
            Isotope::Tm176 => None,
            Isotope::Tm177 => None,
            Isotope::Tm178 => None,
            Isotope::Tm179 => None,
            Isotope::Tm180 => None,
            Isotope::Tm181 => None,
            Isotope::Tm182 => None,
            Isotope::Yb148 => None,
            Isotope::Yb149 => None,
            Isotope::Yb150 => None,
            Isotope::Yb151 => None,
            Isotope::Yb152 => None,
            Isotope::Yb153 => None,
            Isotope::Yb154 => None,
            Isotope::Yb155 => None,
            Isotope::Yb156 => None,
            Isotope::Yb157 => None,
            Isotope::Yb158 => None,
            Isotope::Yb159 => None,
            Isotope::Yb160 => None,
            Isotope::Yb161 => None,
            Isotope::Yb162 => None,
            Isotope::Yb163 => None,
            Isotope::Yb164 => None,
            Isotope::Yb165 => None,
            Isotope::Yb166 => None,
            Isotope::Yb167 => None,
            Isotope::Yb168 => Some(0.123),
            Isotope::Yb169 => None,
            Isotope::Yb170 => Some(2.982),
            Isotope::Yb171 => Some(14.086),
            Isotope::Yb172 => Some(21.686),
            Isotope::Yb173 => Some(16.103),
            Isotope::Yb174 => Some(32.025),
            Isotope::Yb175 => None,
            Isotope::Yb176 => Some(12.995),
            Isotope::Yb177 => None,
            Isotope::Yb178 => None,
            Isotope::Yb179 => None,
            Isotope::Yb180 => None,
            Isotope::Yb181 => None,
            Isotope::Yb182 => None,
            Isotope::Yb183 => None,
            Isotope::Yb184 => None,
            Isotope::Yb185 => None,
            Isotope::Lu150 => None,
            Isotope::Lu151 => None,
            Isotope::Lu152 => None,
            Isotope::Lu153 => None,
            Isotope::Lu154 => None,
            Isotope::Lu155 => None,
            Isotope::Lu156 => None,
            Isotope::Lu157 => None,
            Isotope::Lu158 => None,
            Isotope::Lu159 => None,
            Isotope::Lu160 => None,
            Isotope::Lu161 => None,
            Isotope::Lu162 => None,
            Isotope::Lu163 => None,
            Isotope::Lu164 => None,
            Isotope::Lu165 => None,
            Isotope::Lu166 => None,
            Isotope::Lu167 => None,
            Isotope::Lu168 => None,
            Isotope::Lu169 => None,
            Isotope::Lu170 => None,
            Isotope::Lu171 => None,
            Isotope::Lu172 => None,
            Isotope::Lu173 => None,
            Isotope::Lu174 => None,
            Isotope::Lu175 => Some(97.401),
            Isotope::Lu176 => Some(2.599),
            Isotope::Lu177 => None,
            Isotope::Lu178 => None,
            Isotope::Lu179 => None,
            Isotope::Lu180 => None,
            Isotope::Lu181 => None,
            Isotope::Lu182 => None,
            Isotope::Lu183 => None,
            Isotope::Lu184 => None,
            Isotope::Lu185 => None,
            Isotope::Lu186 => None,
            Isotope::Lu187 => None,
            Isotope::Lu188 => None,
            Isotope::Hf153 => None,
            Isotope::Hf154 => None,
            Isotope::Hf155 => None,
            Isotope::Hf156 => None,
            Isotope::Hf157 => None,
            Isotope::Hf158 => None,
            Isotope::Hf159 => None,
            Isotope::Hf160 => None,
            Isotope::Hf161 => None,
            Isotope::Hf162 => None,
            Isotope::Hf163 => None,
            Isotope::Hf164 => None,
            Isotope::Hf165 => None,
            Isotope::Hf166 => None,
            Isotope::Hf167 => None,
            Isotope::Hf168 => None,
            Isotope::Hf169 => None,
            Isotope::Hf170 => None,
            Isotope::Hf171 => None,
            Isotope::Hf172 => None,
            Isotope::Hf173 => None,
            Isotope::Hf174 => Some(0.16),
            Isotope::Hf175 => None,
            Isotope::Hf176 => Some(5.26),
            Isotope::Hf177 => Some(18.6),
            Isotope::Hf178 => Some(27.28),
            Isotope::Hf179 => Some(13.62),
            Isotope::Hf180 => Some(35.08),
            Isotope::Hf181 => None,
            Isotope::Hf182 => None,
            Isotope::Hf183 => None,
            Isotope::Hf184 => None,
            Isotope::Hf185 => None,
            Isotope::Hf186 => None,
            Isotope::Hf187 => None,
            Isotope::Hf188 => None,
            Isotope::Hf189 => None,
            Isotope::Hf190 => None,
            Isotope::Ta155 => None,
            Isotope::Ta156 => None,
            Isotope::Ta157 => None,
            Isotope::Ta158 => None,
            Isotope::Ta159 => None,
            Isotope::Ta160 => None,
            Isotope::Ta161 => None,
            Isotope::Ta162 => None,
            Isotope::Ta163 => None,
            Isotope::Ta164 => None,
            Isotope::Ta165 => None,
            Isotope::Ta166 => None,
            Isotope::Ta167 => None,
            Isotope::Ta168 => None,
            Isotope::Ta169 => None,
            Isotope::Ta170 => None,
            Isotope::Ta171 => None,
            Isotope::Ta172 => None,
            Isotope::Ta173 => None,
            Isotope::Ta174 => None,
            Isotope::Ta175 => None,
            Isotope::Ta176 => None,
            Isotope::Ta177 => None,
            Isotope::Ta178 => None,
            Isotope::Ta179 => None,
            Isotope::Ta180 => None,
            Isotope::Ta181 => Some(99.98799),
            Isotope::Ta182 => None,
            Isotope::Ta183 => None,
            Isotope::Ta184 => None,
            Isotope::Ta185 => None,
            Isotope::Ta186 => None,
            Isotope::Ta187 => None,
            Isotope::Ta188 => None,
            Isotope::Ta189 => None,
            Isotope::Ta190 => None,
            Isotope::Ta191 => None,
            Isotope::Ta192 => None,
            Isotope::Ta193 => None,
            Isotope::Ta194 => None,
            Isotope::W157 => None,
            Isotope::W158 => None,
            Isotope::W159 => None,
            Isotope::W160 => None,
            Isotope::W161 => None,
            Isotope::W162 => None,
            Isotope::W163 => None,
            Isotope::W164 => None,
            Isotope::W165 => None,
            Isotope::W166 => None,
            Isotope::W167 => None,
            Isotope::W168 => None,
            Isotope::W169 => None,
            Isotope::W170 => None,
            Isotope::W171 => None,
            Isotope::W172 => None,
            Isotope::W173 => None,
            Isotope::W174 => None,
            Isotope::W175 => None,
            Isotope::W176 => None,
            Isotope::W177 => None,
            Isotope::W178 => None,
            Isotope::W179 => None,
            Isotope::W180 => Some(0.12),
            Isotope::W181 => None,
            Isotope::W182 => Some(26.5),
            Isotope::W183 => Some(14.31),
            Isotope::W184 => Some(30.64),
            Isotope::W185 => None,
            Isotope::W186 => Some(28.43),
            Isotope::W187 => None,
            Isotope::W188 => None,
            Isotope::W189 => None,
            Isotope::W190 => None,
            Isotope::W191 => None,
            Isotope::W192 => None,
            Isotope::W193 => None,
            Isotope::W194 => None,
            Isotope::W195 => None,
            Isotope::W196 => None,
            Isotope::W197 => None,
            Isotope::Re159 => None,
            Isotope::Re160 => None,
            Isotope::Re161 => None,
            Isotope::Re162 => None,
            Isotope::Re163 => None,
            Isotope::Re164 => None,
            Isotope::Re165 => None,
            Isotope::Re166 => None,
            Isotope::Re167 => None,
            Isotope::Re168 => None,
            Isotope::Re169 => None,
            Isotope::Re170 => None,
            Isotope::Re171 => None,
            Isotope::Re172 => None,
            Isotope::Re173 => None,
            Isotope::Re174 => None,
            Isotope::Re175 => None,
            Isotope::Re176 => None,
            Isotope::Re177 => None,
            Isotope::Re178 => None,
            Isotope::Re179 => None,
            Isotope::Re180 => None,
            Isotope::Re181 => None,
            Isotope::Re182 => None,
            Isotope::Re183 => None,
            Isotope::Re184 => None,
            Isotope::Re185 => Some(37.4),
            Isotope::Re186 => None,
            Isotope::Re187 => Some(62.6),
            Isotope::Re188 => None,
            Isotope::Re189 => None,
            Isotope::Re190 => None,
            Isotope::Re191 => None,
            Isotope::Re192 => None,
            Isotope::Re193 => None,
            Isotope::Re194 => None,
            Isotope::Re195 => None,
            Isotope::Re196 => None,
            Isotope::Re197 => None,
            Isotope::Re198 => None,
            Isotope::Re199 => None,
            Isotope::Os161 => None,
            Isotope::Os162 => None,
            Isotope::Os163 => None,
            Isotope::Os164 => None,
            Isotope::Os165 => None,
            Isotope::Os166 => None,
            Isotope::Os167 => None,
            Isotope::Os168 => None,
            Isotope::Os169 => None,
            Isotope::Os170 => None,
            Isotope::Os171 => None,
            Isotope::Os172 => None,
            Isotope::Os173 => None,
            Isotope::Os174 => None,
            Isotope::Os175 => None,
            Isotope::Os176 => None,
            Isotope::Os177 => None,
            Isotope::Os178 => None,
            Isotope::Os179 => None,
            Isotope::Os180 => None,
            Isotope::Os181 => None,
            Isotope::Os182 => None,
            Isotope::Os183 => None,
            Isotope::Os184 => Some(0.02),
            Isotope::Os185 => None,
            Isotope::Os186 => Some(1.59),
            Isotope::Os187 => Some(1.96),
            Isotope::Os188 => Some(13.24),
            Isotope::Os189 => Some(16.15),
            Isotope::Os190 => Some(26.26),
            Isotope::Os191 => None,
            Isotope::Os192 => Some(40.78),
            Isotope::Os193 => None,
            Isotope::Os194 => None,
            Isotope::Os195 => None,
            Isotope::Os196 => None,
            Isotope::Os197 => None,
            Isotope::Os198 => None,
            Isotope::Os199 => None,
            Isotope::Os200 => None,
            Isotope::Os201 => None,
            Isotope::Os202 => None,
            Isotope::Os203 => None,
            Isotope::Ir163 => None,
            Isotope::Ir164 => None,
            Isotope::Ir165 => None,
            Isotope::Ir166 => None,
            Isotope::Ir167 => None,
            Isotope::Ir168 => None,
            Isotope::Ir169 => None,
            Isotope::Ir170 => None,
            Isotope::Ir171 => None,
            Isotope::Ir172 => None,
            Isotope::Ir173 => None,
            Isotope::Ir174 => None,
            Isotope::Ir175 => None,
            Isotope::Ir176 => None,
            Isotope::Ir177 => None,
            Isotope::Ir178 => None,
            Isotope::Ir179 => None,
            Isotope::Ir180 => None,
            Isotope::Ir181 => None,
            Isotope::Ir182 => None,
            Isotope::Ir183 => None,
            Isotope::Ir184 => None,
            Isotope::Ir185 => None,
            Isotope::Ir186 => None,
            Isotope::Ir187 => None,
            Isotope::Ir188 => None,
            Isotope::Ir189 => None,
            Isotope::Ir190 => None,
            Isotope::Ir191 => Some(37.3),
            Isotope::Ir192 => None,
            Isotope::Ir193 => Some(62.7),
            Isotope::Ir194 => None,
            Isotope::Ir195 => None,
            Isotope::Ir196 => None,
            Isotope::Ir197 => None,
            Isotope::Ir198 => None,
            Isotope::Ir199 => None,
            Isotope::Ir200 => None,
            Isotope::Ir201 => None,
            Isotope::Ir202 => None,
            Isotope::Ir203 => None,
            Isotope::Ir204 => None,
            Isotope::Ir205 => None,
            Isotope::Pt165 => None,
            Isotope::Pt166 => None,
            Isotope::Pt167 => None,
            Isotope::Pt168 => None,
            Isotope::Pt169 => None,
            Isotope::Pt170 => None,
            Isotope::Pt171 => None,
            Isotope::Pt172 => None,
            Isotope::Pt173 => None,
            Isotope::Pt174 => None,
            Isotope::Pt175 => None,
            Isotope::Pt176 => None,
            Isotope::Pt177 => None,
            Isotope::Pt178 => None,
            Isotope::Pt179 => None,
            Isotope::Pt180 => None,
            Isotope::Pt181 => None,
            Isotope::Pt182 => None,
            Isotope::Pt183 => None,
            Isotope::Pt184 => None,
            Isotope::Pt185 => None,
            Isotope::Pt186 => None,
            Isotope::Pt187 => None,
            Isotope::Pt188 => None,
            Isotope::Pt189 => None,
            Isotope::Pt190 => Some(0.012),
            Isotope::Pt191 => None,
            Isotope::Pt192 => Some(0.782),
            Isotope::Pt193 => None,
            Isotope::Pt194 => Some(32.864),
            Isotope::Pt195 => Some(33.775),
            Isotope::Pt196 => Some(25.211),
            Isotope::Pt197 => None,
            Isotope::Pt198 => Some(7.356),
            Isotope::Pt199 => None,
            Isotope::Pt200 => None,
            Isotope::Pt201 => None,
            Isotope::Pt202 => None,
            Isotope::Pt203 => None,
            Isotope::Pt204 => None,
            Isotope::Pt205 => None,
            Isotope::Pt206 => None,
            Isotope::Pt207 => None,
            Isotope::Pt208 => None,
            Isotope::Au168 => None,
            Isotope::Au169 => None,
            Isotope::Au170 => None,
            Isotope::Au171 => None,
            Isotope::Au172 => None,
            Isotope::Au173 => None,
            Isotope::Au174 => None,
            Isotope::Au175 => None,
            Isotope::Au176 => None,
            Isotope::Au177 => None,
            Isotope::Au178 => None,
            Isotope::Au179 => None,
            Isotope::Au180 => None,
            Isotope::Au181 => None,
            Isotope::Au182 => None,
            Isotope::Au183 => None,
            Isotope::Au184 => None,
            Isotope::Au185 => None,
            Isotope::Au186 => None,
            Isotope::Au187 => None,
            Isotope::Au188 => None,
            Isotope::Au189 => None,
            Isotope::Au190 => None,
            Isotope::Au191 => None,
            Isotope::Au192 => None,
            Isotope::Au193 => None,
            Isotope::Au194 => None,
            Isotope::Au195 => None,
            Isotope::Au196 => None,
            Isotope::Au197 => Some(100.0),
            Isotope::Au198 => None,
            Isotope::Au199 => None,
            Isotope::Au200 => None,
            Isotope::Au201 => None,
            Isotope::Au202 => None,
            Isotope::Au203 => None,
            Isotope::Au204 => None,
            Isotope::Au205 => None,
            Isotope::Au206 => None,
            Isotope::Au207 => None,
            Isotope::Au208 => None,
            Isotope::Au209 => None,
            Isotope::Au210 => None,
            Isotope::Hg170 => None,
            Isotope::Hg171 => None,
            Isotope::Hg172 => None,
            Isotope::Hg173 => None,
            Isotope::Hg174 => None,
            Isotope::Hg175 => None,
            Isotope::Hg176 => None,
            Isotope::Hg177 => None,
            Isotope::Hg178 => None,
            Isotope::Hg179 => None,
            Isotope::Hg180 => None,
            Isotope::Hg181 => None,
            Isotope::Hg182 => None,
            Isotope::Hg183 => None,
            Isotope::Hg184 => None,
            Isotope::Hg185 => None,
            Isotope::Hg186 => None,
            Isotope::Hg187 => None,
            Isotope::Hg188 => None,
            Isotope::Hg189 => None,
            Isotope::Hg190 => None,
            Isotope::Hg191 => None,
            Isotope::Hg192 => None,
            Isotope::Hg193 => None,
            Isotope::Hg194 => None,
            Isotope::Hg195 => None,
            Isotope::Hg196 => Some(0.15),
            Isotope::Hg197 => None,
            Isotope::Hg198 => Some(10.04),
            Isotope::Hg199 => Some(16.94),
            Isotope::Hg200 => Some(23.14),
            Isotope::Hg201 => Some(13.17),
            Isotope::Hg202 => Some(29.74),
            Isotope::Hg203 => None,
            Isotope::Hg204 => Some(6.82),
            Isotope::Hg205 => None,
            Isotope::Hg206 => None,
            Isotope::Hg207 => None,
            Isotope::Hg208 => None,
            Isotope::Hg209 => None,
            Isotope::Hg210 => None,
            Isotope::Hg211 => None,
            Isotope::Hg212 => None,
            Isotope::Hg213 => None,
            Isotope::Hg214 => None,
            Isotope::Hg215 => None,
            Isotope::Hg216 => None,
            Isotope::Tl176 => None,
            Isotope::Tl177 => None,
            Isotope::Tl178 => None,
            Isotope::Tl179 => None,
            Isotope::Tl180 => None,
            Isotope::Tl181 => None,
            Isotope::Tl182 => None,
            Isotope::Tl183 => None,
            Isotope::Tl184 => None,
            Isotope::Tl185 => None,
            Isotope::Tl186 => None,
            Isotope::Tl187 => None,
            Isotope::Tl188 => None,
            Isotope::Tl189 => None,
            Isotope::Tl190 => None,
            Isotope::Tl191 => None,
            Isotope::Tl192 => None,
            Isotope::Tl193 => None,
            Isotope::Tl194 => None,
            Isotope::Tl195 => None,
            Isotope::Tl196 => None,
            Isotope::Tl197 => None,
            Isotope::Tl198 => None,
            Isotope::Tl199 => None,
            Isotope::Tl200 => None,
            Isotope::Tl201 => None,
            Isotope::Tl202 => None,
            Isotope::Tl203 => Some(29.515),
            Isotope::Tl204 => None,
            Isotope::Tl205 => Some(70.485),
            Isotope::Tl206 => None,
            Isotope::Tl207 => None,
            Isotope::Tl208 => None,
            Isotope::Tl209 => None,
            Isotope::Tl210 => None,
            Isotope::Tl211 => None,
            Isotope::Tl212 => None,
            Isotope::Tl213 => None,
            Isotope::Tl214 => None,
            Isotope::Tl215 => None,
            Isotope::Tl216 => None,
            Isotope::Tl217 => None,
            Isotope::Tl218 => None,
            Isotope::Pb178 => None,
            Isotope::Pb179 => None,
            Isotope::Pb180 => None,
            Isotope::Pb181 => None,
            Isotope::Pb182 => None,
            Isotope::Pb183 => None,
            Isotope::Pb184 => None,
            Isotope::Pb185 => None,
            Isotope::Pb186 => None,
            Isotope::Pb187 => None,
            Isotope::Pb188 => None,
            Isotope::Pb189 => None,
            Isotope::Pb190 => None,
            Isotope::Pb191 => None,
            Isotope::Pb192 => None,
            Isotope::Pb193 => None,
            Isotope::Pb194 => None,
            Isotope::Pb195 => None,
            Isotope::Pb196 => None,
            Isotope::Pb197 => None,
            Isotope::Pb198 => None,
            Isotope::Pb199 => None,
            Isotope::Pb200 => None,
            Isotope::Pb201 => None,
            Isotope::Pb202 => None,
            Isotope::Pb203 => None,
            Isotope::Pb204 => Some(1.4),
            Isotope::Pb205 => None,
            Isotope::Pb206 => Some(24.1),
            Isotope::Pb207 => Some(22.1),
            Isotope::Pb208 => Some(52.4),
            Isotope::Pb209 => None,
            Isotope::Pb210 => None,
            Isotope::Pb211 => None,
            Isotope::Pb212 => None,
            Isotope::Pb213 => None,
            Isotope::Pb214 => None,
            Isotope::Pb215 => None,
            Isotope::Pb216 => None,
            Isotope::Pb217 => None,
            Isotope::Pb218 => None,
            Isotope::Pb219 => None,
            Isotope::Pb220 => None,
            Isotope::Bi184 => None,
            Isotope::Bi185 => None,
            Isotope::Bi186 => None,
            Isotope::Bi187 => None,
            Isotope::Bi188 => None,
            Isotope::Bi189 => None,
            Isotope::Bi190 => None,
            Isotope::Bi191 => None,
            Isotope::Bi192 => None,
            Isotope::Bi193 => None,
            Isotope::Bi194 => None,
            Isotope::Bi195 => None,
            Isotope::Bi196 => None,
            Isotope::Bi197 => None,
            Isotope::Bi198 => None,
            Isotope::Bi199 => None,
            Isotope::Bi200 => None,
            Isotope::Bi201 => None,
            Isotope::Bi202 => None,
            Isotope::Bi203 => None,
            Isotope::Bi204 => None,
            Isotope::Bi205 => None,
            Isotope::Bi206 => None,
            Isotope::Bi207 => None,
            Isotope::Bi208 => None,
            Isotope::Bi209 => Some(100.0),
            Isotope::Bi210 => None,
            Isotope::Bi211 => None,
            Isotope::Bi212 => None,
            Isotope::Bi213 => None,
            Isotope::Bi214 => None,
            Isotope::Bi215 => None,
            Isotope::Bi216 => None,
            Isotope::Bi217 => None,
            Isotope::Bi218 => None,
            Isotope::Bi219 => None,
            Isotope::Bi220 => None,
            Isotope::Bi221 => None,
            Isotope::Bi222 => None,
            Isotope::Bi223 => None,
            Isotope::Bi224 => None,
            Isotope::Po186 => None,
            Isotope::Po187 => None,
            Isotope::Po188 => None,
            Isotope::Po189 => None,
            Isotope::Po190 => None,
            Isotope::Po191 => None,
            Isotope::Po192 => None,
            Isotope::Po193 => None,
            Isotope::Po194 => None,
            Isotope::Po195 => None,
            Isotope::Po196 => None,
            Isotope::Po197 => None,
            Isotope::Po198 => None,
            Isotope::Po199 => None,
            Isotope::Po200 => None,
            Isotope::Po201 => None,
            Isotope::Po202 => None,
            Isotope::Po203 => None,
            Isotope::Po204 => None,
            Isotope::Po205 => None,
            Isotope::Po206 => None,
            Isotope::Po207 => None,
            Isotope::Po208 => None,
            Isotope::Po209 => None,
            Isotope::Po210 => None,
            Isotope::Po211 => None,
            Isotope::Po212 => None,
            Isotope::Po213 => None,
            Isotope::Po214 => None,
            Isotope::Po215 => None,
            Isotope::Po216 => None,
            Isotope::Po217 => None,
            Isotope::Po218 => None,
            Isotope::Po219 => None,
            Isotope::Po220 => None,
            Isotope::Po221 => None,
            Isotope::Po222 => None,
            Isotope::Po223 => None,
            Isotope::Po224 => None,
            Isotope::Po225 => None,
            Isotope::Po226 => None,
            Isotope::Po227 => None,
            Isotope::At191 => None,
            Isotope::At192 => None,
            Isotope::At193 => None,
            Isotope::At194 => None,
            Isotope::At195 => None,
            Isotope::At196 => None,
            Isotope::At197 => None,
            Isotope::At198 => None,
            Isotope::At199 => None,
            Isotope::At200 => None,
            Isotope::At201 => None,
            Isotope::At202 => None,
            Isotope::At203 => None,
            Isotope::At204 => None,
            Isotope::At205 => None,
            Isotope::At206 => None,
            Isotope::At207 => None,
            Isotope::At208 => None,
            Isotope::At209 => None,
            Isotope::At210 => None,
            Isotope::At211 => None,
            Isotope::At212 => None,
            Isotope::At213 => None,
            Isotope::At214 => None,
            Isotope::At215 => None,
            Isotope::At216 => None,
            Isotope::At217 => None,
            Isotope::At218 => None,
            Isotope::At219 => None,
            Isotope::At220 => None,
            Isotope::At221 => None,
            Isotope::At222 => None,
            Isotope::At223 => None,
            Isotope::At224 => None,
            Isotope::At225 => None,
            Isotope::At226 => None,
            Isotope::At227 => None,
            Isotope::At228 => None,
            Isotope::At229 => None,
            Isotope::Rn193 => None,
            Isotope::Rn194 => None,
            Isotope::Rn195 => None,
            Isotope::Rn196 => None,
            Isotope::Rn197 => None,
            Isotope::Rn198 => None,
            Isotope::Rn199 => None,
            Isotope::Rn200 => None,
            Isotope::Rn201 => None,
            Isotope::Rn202 => None,
            Isotope::Rn203 => None,
            Isotope::Rn204 => None,
            Isotope::Rn205 => None,
            Isotope::Rn206 => None,
            Isotope::Rn207 => None,
            Isotope::Rn208 => None,
            Isotope::Rn209 => None,
            Isotope::Rn210 => None,
            Isotope::Rn211 => None,
            Isotope::Rn212 => None,
            Isotope::Rn213 => None,
            Isotope::Rn214 => None,
            Isotope::Rn215 => None,
            Isotope::Rn216 => None,
            Isotope::Rn217 => None,
            Isotope::Rn218 => None,
            Isotope::Rn219 => None,
            Isotope::Rn220 => None,
            Isotope::Rn221 => None,
            Isotope::Rn222 => None,
            Isotope::Rn223 => None,
            Isotope::Rn224 => None,
            Isotope::Rn225 => None,
            Isotope::Rn226 => None,
            Isotope::Rn227 => None,
            Isotope::Rn228 => None,
            Isotope::Rn229 => None,
            Isotope::Rn230 => None,
            Isotope::Rn231 => None,
            Isotope::Fr197 => None,
            Isotope::Fr198 => None,
            Isotope::Fr199 => None,
            Isotope::Fr200 => None,
            Isotope::Fr201 => None,
            Isotope::Fr202 => None,
            Isotope::Fr203 => None,
            Isotope::Fr204 => None,
            Isotope::Fr205 => None,
            Isotope::Fr206 => None,
            Isotope::Fr207 => None,
            Isotope::Fr208 => None,
            Isotope::Fr209 => None,
            Isotope::Fr210 => None,
            Isotope::Fr211 => None,
            Isotope::Fr212 => None,
            Isotope::Fr213 => None,
            Isotope::Fr214 => None,
            Isotope::Fr215 => None,
            Isotope::Fr216 => None,
            Isotope::Fr217 => None,
            Isotope::Fr218 => None,
            Isotope::Fr219 => None,
            Isotope::Fr220 => None,
            Isotope::Fr221 => None,
            Isotope::Fr222 => None,
            Isotope::Fr223 => None,
            Isotope::Fr224 => None,
            Isotope::Fr225 => None,
            Isotope::Fr226 => None,
            Isotope::Fr227 => None,
            Isotope::Fr228 => None,
            Isotope::Fr229 => None,
            Isotope::Fr230 => None,
            Isotope::Fr231 => None,
            Isotope::Fr232 => None,
            Isotope::Fr233 => None,
            Isotope::Ra201 => None,
            Isotope::Ra202 => None,
            Isotope::Ra203 => None,
            Isotope::Ra204 => None,
            Isotope::Ra205 => None,
            Isotope::Ra206 => None,
            Isotope::Ra207 => None,
            Isotope::Ra208 => None,
            Isotope::Ra209 => None,
            Isotope::Ra210 => None,
            Isotope::Ra211 => None,
            Isotope::Ra212 => None,
            Isotope::Ra213 => None,
            Isotope::Ra214 => None,
            Isotope::Ra215 => None,
            Isotope::Ra216 => None,
            Isotope::Ra217 => None,
            Isotope::Ra218 => None,
            Isotope::Ra219 => None,
            Isotope::Ra220 => None,
            Isotope::Ra221 => None,
            Isotope::Ra222 => None,
            Isotope::Ra223 => None,
            Isotope::Ra224 => None,
            Isotope::Ra225 => None,
            Isotope::Ra226 => None,
            Isotope::Ra227 => None,
            Isotope::Ra228 => None,
            Isotope::Ra229 => None,
            Isotope::Ra230 => None,
            Isotope::Ra231 => None,
            Isotope::Ra232 => None,
            Isotope::Ra233 => None,
            Isotope::Ra234 => None,
            Isotope::Ra235 => None,
            Isotope::Ac205 => None,
            Isotope::Ac206 => None,
            Isotope::Ac207 => None,
            Isotope::Ac208 => None,
            Isotope::Ac209 => None,
            Isotope::Ac210 => None,
            Isotope::Ac211 => None,
            Isotope::Ac212 => None,
            Isotope::Ac213 => None,
            Isotope::Ac214 => None,
            Isotope::Ac215 => None,
            Isotope::Ac216 => None,
            Isotope::Ac217 => None,
            Isotope::Ac218 => None,
            Isotope::Ac219 => None,
            Isotope::Ac220 => None,
            Isotope::Ac221 => None,
            Isotope::Ac222 => None,
            Isotope::Ac223 => None,
            Isotope::Ac224 => None,
            Isotope::Ac225 => None,
            Isotope::Ac226 => None,
            Isotope::Ac227 => None,
            Isotope::Ac228 => None,
            Isotope::Ac229 => None,
            Isotope::Ac230 => None,
            Isotope::Ac231 => None,
            Isotope::Ac232 => None,
            Isotope::Ac233 => None,
            Isotope::Ac234 => None,
            Isotope::Ac235 => None,
            Isotope::Ac236 => None,
            Isotope::Ac237 => None,
            Isotope::Th208 => None,
            Isotope::Th209 => None,
            Isotope::Th210 => None,
            Isotope::Th211 => None,
            Isotope::Th212 => None,
            Isotope::Th213 => None,
            Isotope::Th214 => None,
            Isotope::Th215 => None,
            Isotope::Th216 => None,
            Isotope::Th217 => None,
            Isotope::Th218 => None,
            Isotope::Th219 => None,
            Isotope::Th220 => None,
            Isotope::Th221 => None,
            Isotope::Th222 => None,
            Isotope::Th223 => None,
            Isotope::Th224 => None,
            Isotope::Th225 => None,
            Isotope::Th226 => None,
            Isotope::Th227 => None,
            Isotope::Th228 => None,
            Isotope::Th229 => None,
            Isotope::Th230 => Some(0.02),
            Isotope::Th231 => None,
            Isotope::Th232 => Some(99.98),
            Isotope::Th233 => None,
            Isotope::Th234 => None,
            Isotope::Th235 => None,
            Isotope::Th236 => None,
            Isotope::Th237 => None,
            Isotope::Th238 => None,
            Isotope::Th239 => None,
            Isotope::Pa211 => None,
            Isotope::Pa212 => None,
            Isotope::Pa213 => None,
            Isotope::Pa214 => None,
            Isotope::Pa215 => None,
            Isotope::Pa216 => None,
            Isotope::Pa217 => None,
            Isotope::Pa218 => None,
            Isotope::Pa219 => None,
            Isotope::Pa220 => None,
            Isotope::Pa221 => None,
            Isotope::Pa222 => None,
            Isotope::Pa223 => None,
            Isotope::Pa224 => None,
            Isotope::Pa225 => None,
            Isotope::Pa226 => None,
            Isotope::Pa227 => None,
            Isotope::Pa228 => None,
            Isotope::Pa229 => None,
            Isotope::Pa230 => None,
            Isotope::Pa231 => Some(100.0),
            Isotope::Pa232 => None,
            Isotope::Pa233 => None,
            Isotope::Pa234 => None,
            Isotope::Pa235 => None,
            Isotope::Pa236 => None,
            Isotope::Pa237 => None,
            Isotope::Pa238 => None,
            Isotope::Pa239 => None,
            Isotope::Pa240 => None,
            Isotope::Pa241 => None,
            Isotope::U215 => None,
            Isotope::U216 => None,
            Isotope::U217 => None,
            Isotope::U218 => None,
            Isotope::U219 => None,
            Isotope::U220 => None,
            Isotope::U221 => None,
            Isotope::U222 => None,
            Isotope::U223 => None,
            Isotope::U224 => None,
            Isotope::U225 => None,
            Isotope::U226 => None,
            Isotope::U227 => None,
            Isotope::U228 => None,
            Isotope::U229 => None,
            Isotope::U230 => None,
            Isotope::U231 => None,
            Isotope::U232 => None,
            Isotope::U233 => None,
            Isotope::U234 => Some(0.0054),
            Isotope::U235 => Some(0.7204),
            Isotope::U236 => None,
            Isotope::U237 => None,
            Isotope::U238 => Some(99.2742),
            Isotope::U239 => None,
            Isotope::U240 => None,
            Isotope::U241 => None,
            Isotope::U242 => None,
            Isotope::U243 => None,
            Isotope::Np219 => None,
            Isotope::Np220 => None,
            Isotope::Np221 => None,
            Isotope::Np222 => None,
            Isotope::Np223 => None,
            Isotope::Np224 => None,
            Isotope::Np225 => None,
            Isotope::Np226 => None,
            Isotope::Np227 => None,
            Isotope::Np228 => None,
            Isotope::Np229 => None,
            Isotope::Np230 => None,
            Isotope::Np231 => None,
            Isotope::Np232 => None,
            Isotope::Np233 => None,
            Isotope::Np234 => None,
            Isotope::Np235 => None,
            Isotope::Np236 => None,
            Isotope::Np237 => None,
            Isotope::Np238 => None,
            Isotope::Np239 => None,
            Isotope::Np240 => None,
            Isotope::Np241 => None,
            Isotope::Np242 => None,
            Isotope::Np243 => None,
            Isotope::Np244 => None,
            Isotope::Np245 => None,
            Isotope::Pu221 => None,
            Isotope::Pu222 => None,
            Isotope::Pu223 => None,
            Isotope::Pu224 => None,
            Isotope::Pu225 => None,
            Isotope::Pu226 => None,
            Isotope::Pu227 => None,
            Isotope::Pu228 => None,
            Isotope::Pu229 => None,
            Isotope::Pu230 => None,
            Isotope::Pu231 => None,
            Isotope::Pu232 => None,
            Isotope::Pu233 => None,
            Isotope::Pu234 => None,
            Isotope::Pu235 => None,
            Isotope::Pu236 => None,
            Isotope::Pu237 => None,
            Isotope::Pu238 => None,
            Isotope::Pu239 => None,
            Isotope::Pu240 => None,
            Isotope::Pu241 => None,
            Isotope::Pu242 => None,
            Isotope::Pu243 => None,
            Isotope::Pu244 => None,
            Isotope::Pu245 => None,
            Isotope::Pu246 => None,
            Isotope::Pu247 => None,
            Isotope::Am223 => None,
            Isotope::Am224 => None,
            Isotope::Am225 => None,
            Isotope::Am226 => None,
            Isotope::Am227 => None,
            Isotope::Am228 => None,
            Isotope::Am229 => None,
            Isotope::Am230 => None,
            Isotope::Am231 => None,
            Isotope::Am232 => None,
            Isotope::Am233 => None,
            Isotope::Am234 => None,
            Isotope::Am235 => None,
            Isotope::Am236 => None,
            Isotope::Am237 => None,
            Isotope::Am238 => None,
            Isotope::Am239 => None,
            Isotope::Am240 => None,
            Isotope::Am241 => None,
            Isotope::Am242 => None,
            Isotope::Am243 => None,
            Isotope::Am244 => None,
            Isotope::Am245 => None,
            Isotope::Am246 => None,
            Isotope::Am247 => None,
            Isotope::Am248 => None,
            Isotope::Am249 => None,
            Isotope::Cm231 => None,
            Isotope::Cm232 => None,
            Isotope::Cm233 => None,
            Isotope::Cm234 => None,
            Isotope::Cm235 => None,
            Isotope::Cm236 => None,
            Isotope::Cm237 => None,
            Isotope::Cm238 => None,
            Isotope::Cm239 => None,
            Isotope::Cm240 => None,
            Isotope::Cm241 => None,
            Isotope::Cm242 => None,
            Isotope::Cm243 => None,
            Isotope::Cm244 => None,
            Isotope::Cm245 => None,
            Isotope::Cm246 => None,
            Isotope::Cm247 => None,
            Isotope::Cm248 => None,
            Isotope::Cm249 => None,
            Isotope::Cm250 => None,
            Isotope::Cm251 => None,
            Isotope::Cm252 => None,
            Isotope::Bk233 => None,
            Isotope::Bk234 => None,
            Isotope::Bk235 => None,
            Isotope::Bk236 => None,
            Isotope::Bk237 => None,
            Isotope::Bk238 => None,
            Isotope::Bk239 => None,
            Isotope::Bk240 => None,
            Isotope::Bk241 => None,
            Isotope::Bk242 => None,
            Isotope::Bk243 => None,
            Isotope::Bk244 => None,
            Isotope::Bk245 => None,
            Isotope::Bk246 => None,
            Isotope::Bk247 => None,
            Isotope::Bk248 => None,
            Isotope::Bk249 => None,
            Isotope::Bk250 => None,
            Isotope::Bk251 => None,
            Isotope::Bk252 => None,
            Isotope::Bk253 => None,
            Isotope::Bk254 => None,
            Isotope::Cf237 => None,
            Isotope::Cf238 => None,
            Isotope::Cf239 => None,
            Isotope::Cf240 => None,
            Isotope::Cf241 => None,
            Isotope::Cf242 => None,
            Isotope::Cf243 => None,
            Isotope::Cf244 => None,
            Isotope::Cf245 => None,
            Isotope::Cf246 => None,
            Isotope::Cf247 => None,
            Isotope::Cf248 => None,
            Isotope::Cf249 => None,
            Isotope::Cf250 => None,
            Isotope::Cf251 => None,
            Isotope::Cf252 => None,
            Isotope::Cf253 => None,
            Isotope::Cf254 => None,
            Isotope::Cf255 => None,
            Isotope::Cf256 => None,
            Isotope::Es239 => None,
            Isotope::Es240 => None,
            Isotope::Es241 => None,
            Isotope::Es242 => None,
            Isotope::Es243 => None,
            Isotope::Es244 => None,
            Isotope::Es245 => None,
            Isotope::Es246 => None,
            Isotope::Es247 => None,
            Isotope::Es248 => None,
            Isotope::Es249 => None,
            Isotope::Es250 => None,
            Isotope::Es251 => None,
            Isotope::Es252 => None,
            Isotope::Es253 => None,
            Isotope::Es254 => None,
            Isotope::Es255 => None,
            Isotope::Es256 => None,
            Isotope::Es257 => None,
            Isotope::Es258 => None,
            Isotope::Fm241 => None,
            Isotope::Fm242 => None,
            Isotope::Fm243 => None,
            Isotope::Fm244 => None,
            Isotope::Fm245 => None,
            Isotope::Fm246 => None,
            Isotope::Fm247 => None,
            Isotope::Fm248 => None,
            Isotope::Fm249 => None,
            Isotope::Fm250 => None,
            Isotope::Fm251 => None,
            Isotope::Fm252 => None,
            Isotope::Fm253 => None,
            Isotope::Fm254 => None,
            Isotope::Fm255 => None,
            Isotope::Fm256 => None,
            Isotope::Fm257 => None,
            Isotope::Fm258 => None,
            Isotope::Fm259 => None,
            Isotope::Fm260 => None,
            Isotope::Md244 => None,
            Isotope::Md245 => None,
            Isotope::Md246 => None,
            Isotope::Md247 => None,
            Isotope::Md248 => None,
            Isotope::Md249 => None,
            Isotope::Md250 => None,
            Isotope::Md251 => None,
            Isotope::Md252 => None,
            Isotope::Md253 => None,
            Isotope::Md254 => None,
            Isotope::Md255 => None,
            Isotope::Md256 => None,
            Isotope::Md257 => None,
            Isotope::Md258 => None,
            Isotope::Md259 => None,
            Isotope::Md260 => None,
            Isotope::Md261 => None,
            Isotope::Md262 => None,
            Isotope::No248 => None,
            Isotope::No249 => None,
            Isotope::No250 => None,
            Isotope::No251 => None,
            Isotope::No252 => None,
            Isotope::No253 => None,
            Isotope::No254 => None,
            Isotope::No255 => None,
            Isotope::No256 => None,
            Isotope::No257 => None,
            Isotope::No258 => None,
            Isotope::No259 => None,
            Isotope::No260 => None,
            Isotope::No261 => None,
            Isotope::No262 => None,
            Isotope::No263 => None,
            Isotope::No264 => None,
            Isotope::Lr251 => None,
            Isotope::Lr252 => None,
            Isotope::Lr253 => None,
            Isotope::Lr254 => None,
            Isotope::Lr255 => None,
            Isotope::Lr256 => None,
            Isotope::Lr257 => None,
            Isotope::Lr258 => None,
            Isotope::Lr259 => None,
            Isotope::Lr260 => None,
            Isotope::Lr261 => None,
            Isotope::Lr262 => None,
            Isotope::Lr263 => None,
            Isotope::Lr264 => None,
            Isotope::Lr265 => None,
            Isotope::Lr266 => None,
            Isotope::Rf253 => None,
            Isotope::Rf254 => None,
            Isotope::Rf255 => None,
            Isotope::Rf256 => None,
            Isotope::Rf257 => None,
            Isotope::Rf258 => None,
            Isotope::Rf259 => None,
            Isotope::Rf260 => None,
            Isotope::Rf261 => None,
            Isotope::Rf262 => None,
            Isotope::Rf263 => None,
            Isotope::Rf264 => None,
            Isotope::Rf265 => None,
            Isotope::Rf266 => None,
            Isotope::Rf267 => None,
            Isotope::Rf268 => None,
            Isotope::Db255 => None,
            Isotope::Db256 => None,
            Isotope::Db257 => None,
            Isotope::Db258 => None,
            Isotope::Db259 => None,
            Isotope::Db260 => None,
            Isotope::Db261 => None,
            Isotope::Db262 => None,
            Isotope::Db263 => None,
            Isotope::Db264 => None,
            Isotope::Db265 => None,
            Isotope::Db266 => None,
            Isotope::Db267 => None,
            Isotope::Db268 => None,
            Isotope::Db269 => None,
            Isotope::Db270 => None,
            Isotope::Sg258 => None,
            Isotope::Sg259 => None,
            Isotope::Sg260 => None,
            Isotope::Sg261 => None,
            Isotope::Sg262 => None,
            Isotope::Sg263 => None,
            Isotope::Sg264 => None,
            Isotope::Sg265 => None,
            Isotope::Sg266 => None,
            Isotope::Sg267 => None,
            Isotope::Sg268 => None,
            Isotope::Sg269 => None,
            Isotope::Sg270 => None,
            Isotope::Sg271 => None,
            Isotope::Sg272 => None,
            Isotope::Sg273 => None,
            Isotope::Bh260 => None,
            Isotope::Bh261 => None,
            Isotope::Bh262 => None,
            Isotope::Bh263 => None,
            Isotope::Bh264 => None,
            Isotope::Bh265 => None,
            Isotope::Bh266 => None,
            Isotope::Bh267 => None,
            Isotope::Bh268 => None,
            Isotope::Bh269 => None,
            Isotope::Bh270 => None,
            Isotope::Bh271 => None,
            Isotope::Bh272 => None,
            Isotope::Bh273 => None,
            Isotope::Bh274 => None,
            Isotope::Bh275 => None,
            Isotope::Bh276 => None,
            Isotope::Bh277 => None,
            Isotope::Bh278 => None,
            Isotope::Hs263 => None,
            Isotope::Hs264 => None,
            Isotope::Hs265 => None,
            Isotope::Hs266 => None,
            Isotope::Hs267 => None,
            Isotope::Hs268 => None,
            Isotope::Hs269 => None,
            Isotope::Hs270 => None,
            Isotope::Hs271 => None,
            Isotope::Hs272 => None,
            Isotope::Hs273 => None,
            Isotope::Hs274 => None,
            Isotope::Hs275 => None,
            Isotope::Hs276 => None,
            Isotope::Hs277 => None,
            Isotope::Hs278 => None,
            Isotope::Hs279 => None,
            Isotope::Hs280 => None,
            Isotope::Mt265 => None,
            Isotope::Mt266 => None,
            Isotope::Mt267 => None,
            Isotope::Mt268 => None,
            Isotope::Mt269 => None,
            Isotope::Mt270 => None,
            Isotope::Mt271 => None,
            Isotope::Mt272 => None,
            Isotope::Mt273 => None,
            Isotope::Mt274 => None,
            Isotope::Mt275 => None,
            Isotope::Mt276 => None,
            Isotope::Mt277 => None,
            Isotope::Mt278 => None,
            Isotope::Mt279 => None,
            Isotope::Mt280 => None,
            Isotope::Mt281 => None,
            Isotope::Mt282 => None,
            Isotope::Ds267 => None,
            Isotope::Ds268 => None,
            Isotope::Ds269 => None,
            Isotope::Ds270 => None,
            Isotope::Ds271 => None,
            Isotope::Ds272 => None,
            Isotope::Ds273 => None,
            Isotope::Ds274 => None,
            Isotope::Ds275 => None,
            Isotope::Ds276 => None,
            Isotope::Ds277 => None,
            Isotope::Ds278 => None,
            Isotope::Ds279 => None,
            Isotope::Ds280 => None,
            Isotope::Ds281 => None,
            Isotope::Ds282 => None,
            Isotope::Ds283 => None,
            Isotope::Ds284 => None,
            Isotope::Rg272 => None,
            Isotope::Rg273 => None,
            Isotope::Rg274 => None,
            Isotope::Rg275 => None,
            Isotope::Rg276 => None,
            Isotope::Rg277 => None,
            Isotope::Rg278 => None,
            Isotope::Rg279 => None,
            Isotope::Rg280 => None,
            Isotope::Rg281 => None,
            Isotope::Rg282 => None,
            Isotope::Rg283 => None,
            Isotope::Rg284 => None,
            Isotope::Rg285 => None,
            Isotope::Rg286 => None,
            Isotope::Cn276 => None,
            Isotope::Cn277 => None,
            Isotope::Cn278 => None,
            Isotope::Cn279 => None,
            Isotope::Cn280 => None,
            Isotope::Cn281 => None,
            Isotope::Cn282 => None,
            Isotope::Cn283 => None,
            Isotope::Cn284 => None,
            Isotope::Cn285 => None,
            Isotope::Cn286 => None,
            Isotope::Cn287 => None,
            Isotope::Cn288 => None,
            Isotope::Nh278 => None,
            Isotope::Nh279 => None,
            Isotope::Nh280 => None,
            Isotope::Nh281 => None,
            Isotope::Nh282 => None,
            Isotope::Nh283 => None,
            Isotope::Nh284 => None,
            Isotope::Nh285 => None,
            Isotope::Nh286 => None,
            Isotope::Nh287 => None,
            Isotope::Nh288 => None,
            Isotope::Nh289 => None,
            Isotope::Nh290 => None,
            Isotope::Fl284 => None,
            Isotope::Fl285 => None,
            Isotope::Fl286 => None,
            Isotope::Fl287 => None,
            Isotope::Fl288 => None,
            Isotope::Fl289 => None,
            Isotope::Fl290 => None,
            Isotope::Fl291 => None,
            Isotope::Mc287 => None,
            Isotope::Mc288 => None,
            Isotope::Mc289 => None,
            Isotope::Mc290 => None,
            Isotope::Mc291 => None,
            Isotope::Mc292 => None,
            Isotope::Lv289 => None,
            Isotope::Lv290 => None,
            Isotope::Lv291 => None,
            Isotope::Lv292 => None,
            Isotope::Lv293 => None,
            Isotope::Ts291 => None,
            Isotope::Ts292 => None,
            Isotope::Ts293 => None,
            Isotope::Ts294 => None,
            Isotope::Og293 => None,
            Isotope::Og294 => None,
            Isotope::Og295 => None,
        }
    }
}
